@@ -28,4 +28,4 @@ ETC="$DIR"/../etc
 DEBUG_PATH="/tmp/receiver.debug"
 
 echo "Launching receiver (which manages passive data) in debug mode to the file $DEBUG_PATH"
-"$BIN"/shinken-receiver -d -c "$ETC"/receiverd.ini --debug "$DEBUG_PATH"
+"$BIN"/shinken-receiver -d -c "$ETC"/daemons/receiverd.ini --debug "$DEBUG_PATH"
