@@ -69,12 +69,11 @@ except ImportError:
 
 
 from shinken.bin import VERSION
-from shinken.pyro_wrapper import PYRO_VERSION
 from shinken.daemons.arbiterdaemon import Arbiter
 
 parser = optparse.OptionParser(
     "%prog [options] -c configfile [-c additional_config_file]",
-    version="%prog: " + VERSION + "     with pyro: " + PYRO_VERSION)
+    version="%prog: " + VERSION)
 parser.add_option('-c', '--config', action='append',
                   dest="config_files", metavar="CONFIG-FILE",
                   help=('Config file (your nagios.cfg). Multiple -c can be '
@@ -99,7 +98,7 @@ parser.add_option("-a", "--analyse",
                   help="Dump an analyse statistics file, for support")
 parser.add_option("-m", "--migrate",
                   dest="migrate",
-                  help="Migrate the raw configuration read from the arbier to another module. --> VERY EXPERIMENTAL!")
+                  help="Migrate the raw configuration read from the arbiter to another module. --> VERY EXPERIMENTAL!")
 parser.add_option("-n", "--name",
                   dest="arb_name",
                   help="Give the arbiter name to use. Optionnal, will use the hostaddress if not provide to find it.")
