@@ -27,4 +27,4 @@ BIN="$DIR"/../bin
 ETC="$DIR"/../etc
 
 echo "Stopping reactionner"
-kill $(cat "$DIR"/../var/reactionnerd.pid)
+kill $(cat /var/run/shinken/reactionnerd.pid)
