@@ -31,16 +31,12 @@ Shinken.
 
 import sys
 
-VERSION = "1.4.1"
+VERSION = "2.0.3"
 
 
-# Make sure people are using Python 2.4 or higher
-if sys.version_info < (2, 4):
-    sys.exit("Shinken requires as a minimum Python 2.4.x, sorry")
+# Make sure people are using Python 2.6 or higher
+if sys.version_info < (2, 6):
+    sys.exit("Shinken requires as a minimum Python 2.6.x, sorry")
 elif sys.version_info >= (3,):
     sys.exit("Shinken is not yet compatible with Python 3.x, sorry")
 
-try:
-    import shinken.pyro_wrapper
-except ImportError:
-    sys.exit("Shinken requires the Python Pyro module. Please install it.")
