@@ -31,6 +31,13 @@ import signal
 import select
 import random
 import ConfigParser
+import json
+import threading
+import inspect
+import traceback
+import cStringIO
+import logging
+import inspect
 
 # Try to see if we are in an android device or not
 is_android = True
@@ -39,16 +46,16 @@ try:
 except ImportError:
     is_android = False
 
-
 if not is_android:
     from multiprocessing import Queue, Manager, active_children, cpu_count
+    from multiprocessing.managers import SyncManager
 else:
     from multiprocessing import active_children
 
-import shinken.pyro_wrapper as pyro
-from shinken.pyro_wrapper import InvalidWorkDir, Pyro
-
+import http_daemon
+from shinken.http_daemon import HTTPDaemon, InvalidWorkDir
 from shinken.log import logger
+from shinken.modulesctx import modulesctx
 from shinken.modulesmanager import ModulesManager
 from shinken.property import StringProp, BoolProp, PathProp, ConfigPathProp, IntegerProp, LogLevelProp
 
@@ -66,8 +73,6 @@ try:
     def get_cur_group():
         return grp.getgrgid(os.getgid()).gr_name
 except ImportError, exp:  # Like in nt system or Android
-
-
     # temporary workaround:
     def get_cur_user():
         return "shinken"
@@ -76,6 +81,7 @@ except ImportError, exp:  # Like in nt system or Android
     def get_cur_group():
         return "shinken"
 
+
 ##########################   DAEMON PART    ###############################
 # The standard I/O file descriptors are redirected to /dev/null by default.
 REDIRECT_TO = getattr(os, "devnull", "/dev/null")
@@ -87,40 +93,105 @@ from shinken.bin import VERSION
 class InvalidPidFile(Exception): pass
 
 
-""" Interface for pyro communications """
-class Interface(Pyro.core.ObjBase, object):
+""" Interface for Inter satellites communications """
+class Interface(object):
 
     #  'app' is to be set to the owner of this interface.
     def __init__(self, app):
-
-        Pyro.core.ObjBase.__init__(self)
-
         self.app = app
         self.running_id = "%d.%d" % (time.time(), random.random())
 
+    
+    doc = 'Test the connexion to the daemon. Returns: pong'
     def ping(self):
         return "pong"
+    ping.need_lock = False
+    ping.doc = doc
 
+
+    doc = 'Get the current running id of the daemon (scheduler)'
     def get_running_id(self):
         return self.running_id
+    get_running_id.need_lock = False
+    get_running_id.doc = doc
 
+
+    doc = 'Send a new configuration to the daemon (internal)'
     def put_conf(self, conf):
         self.app.new_conf = conf
+    put_conf.method = 'post'
+    put_conf.doc = doc
 
+
+    doc = 'Ask the daemon to wait a new conf'
     def wait_new_conf(self):
         self.app.cur_conf = None
+    wait_new_conf.need_lock = False
+    wait_new_conf.doc = doc
 
+
+    doc = 'Does the daemon got an active configuration'
     def have_conf(self):
         return self.app.cur_conf is not None
+    have_conf.need_lock = False
+    have_conf.doc = doc
 
+    
+    doc = 'Set the current log level in [NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL, UNKNOWN]'
     def set_log_level(self, loglevel):
         return logger.set_level(loglevel)
+    set_log_level.doc = doc
+
+
+    doc = 'Get the current log level in [NOTSET, DEBUG, INFO, WARNING, ERROR, CRITICAL, UNKNOWN]'
+    def get_log_level(self):
+        return {logging.NOTSET: 'NOTSET', logging.DEBUG:'DEBUG',
+                logging.INFO: 'INFO', logging.WARNING: 'WARNING',
+                logging.ERROR : 'ERROR', logging.CRITICAL : 'CRITICAL'}.get(logger._level, 'UNKNOWN')
+    get_log_level.doc = doc
+
+    doc = 'List the methods available on the daemon'
+    def api(self):
+        return self.app.http_daemon.registered_fun_names
+    api.doc = doc
+
+
+    doc = 'List the api methods and their parameters'
+    def api_full(self):
+        res = {}
+        for (fname, f) in self.app.http_daemon.registered_fun.iteritems():
+            fclean = fname.replace('_', '-')
+            argspec = inspect.getargspec(f)
+            args = [a for a in argspec.args if a != 'self']
+            defaults = self.app.http_daemon.registered_fun_defaults.get(fname, {})
+            e = {}
+            # Get a string about the args and co
+            _s_nondef_args = ', '.join([a for a in args if a not in defaults])
+            _s_def_args = ', '.join( ['%s=%s' % (k,v) for (k,v) in defaults.iteritems()] )
+            _s_args = ''
+            if _s_nondef_args:
+                _s_args +=_s_nondef_args
+            if _s_def_args:
+                _s_args += ', '+_s_def_args
+            e['proto'] = '%s(%s)' % (fclean, _s_args)
+            e['need_lock'] = getattr(f, 'need_lock', True)
+            e['method'] = getattr(f, 'method', 'GET').upper()
+            e['encode'] = getattr(f, 'encode', 'json')
+            doc = getattr(f, 'doc', '')
+            if doc:
+                e['doc'] = doc
+            res[fclean] = e
+        return res
+    api.doc = doc
+
 
 # If we are under android, we can't give parameters
 if is_android:
     DEFAULT_WORK_DIR = '/sdcard/sl4a/scripts/'
+    DEFAULT_LIB_DIR  = DEFAULT_WORK_DIR
 else:
-    DEFAULT_WORK_DIR = 'var'
+    DEFAULT_WORK_DIR = '/var/run/shinken/'
+    DEFAULT_LIB_DIR  = '/var/lib/shinken/'
 
 
 class Daemon(object):
@@ -134,20 +205,23 @@ class Daemon(object):
         #
         # as returned once the daemon is started.
         'workdir':       PathProp(default=DEFAULT_WORK_DIR),
+        'modules_dir':    PathProp(default=os.path.join(DEFAULT_LIB_DIR, 'modules')),
         'host':          StringProp(default='0.0.0.0'),
         'user':          StringProp(default=get_cur_user()),
         'group':         StringProp(default=get_cur_group()),
         'use_ssl':       BoolProp(default='0'),
-        'certs_dir':     StringProp(default='etc/certs'),
+        'server_key':     StringProp(default='etc/certs/server.key'),
         'ca_cert':       StringProp(default='etc/certs/ca.pem'),
-        'server_cert':   StringProp(default='etc/certs/server.pem'),
+        'server_cert':   StringProp(default='etc/certs/server.cert'),
         'use_local_log': BoolProp(default='1'),
-        'log_level':     LogLevelProp(default='INFO'), # TODO : fix the scheduler so we can put back WARNiING here
+        'log_level':     LogLevelProp(default='WARNING'),
         'hard_ssl_name_check':    BoolProp(default='0'),
         'idontcareaboutsecurity': BoolProp(default='0'),
         'daemon_enabled':BoolProp(default='1'),
         'spare':         BoolProp(default='0'),
         'max_queue_size': IntegerProp(default='0'),
+        'daemon_thread_pool_size': IntegerProp(default='8'),
+        'http_backend':  StringProp(default='auto'),
     }
 
     def __init__(self, name, config_file, is_daemon, do_replace, debug, debug_file):
@@ -168,7 +242,7 @@ class Daemon(object):
         self.t_each_loop = now  # used to track system time change
         self.sleep_time = 0.0  # used to track the time we wait
 
-        self.pyro_daemon = None
+        self.http_daemon = None
 
         # Log init
         #self.log = logger
@@ -195,15 +269,14 @@ class Daemon(object):
         # and be really forked()
         self.manager = None
 
-        self.modules_manager = ModulesManager(name, self.find_modules_path(), [])
-
         os.umask(UMASK)
         self.set_exit_handler()
 
 
     # At least, lose the local log file if needed
     def do_stop(self):
-        if self.modules_manager:
+        # Maybe the modules manager is not even created!
+        if getattr(self, 'modules_manager', None):
             # We save what we can but NOT for the scheduler
             # because the current sched object is a dummy one
             # and the old one has already done it!
@@ -212,9 +285,14 @@ class Daemon(object):
             # And we quit
             print('Stopping all modules')
             self.modules_manager.stop_all()
-            print('Stopping inter-process message (PYRO)')
-        if self.pyro_daemon:
-            pyro.shutdown(self.pyro_daemon)
+            print('Stopping inter-process message')
+        if self.http_daemon:
+            # Release the lock so the daemon can shutdown without problem
+            try:
+                self.http_daemon.lock.release()
+            except:
+                pass
+            self.http_daemon.shutdown()
         logger.quit()
 
 
@@ -254,18 +332,19 @@ class Daemon(object):
                 break
         self.request_stop()
 
+
     def do_load_modules(self):
         self.modules_manager.load_and_init()
         logger.info("I correctly loaded the modules: [%s]" % (','.join([inst.get_name() for inst in self.modules_manager.instances])))
 
+
     # Dummy method for adding broker to this daemon
     def add(self, elt):
         pass
 
+
     def dump_memory(self):
         logger.info("I dump my memory, it can take a minute")
-
-
         try:
             from guppy import hpy
             hp = hpy()
@@ -273,23 +352,34 @@ class Daemon(object):
         except ImportError:
             logger.warning('I do not have the module guppy for memory dump, please install it')
 
+
     def load_config_file(self):
         self.parse_config_file()
         if self.config_file is not None:
             # Some paths can be relatives. We must have a full path by taking
             # the config file by reference
             self.relative_paths_to_full(os.path.dirname(self.config_file))
-            pass
+
+
+    def load_modules_manager(self):
+        self.modules_manager = ModulesManager(self.name, self.find_modules_path(), [])
         # Set the modules watchdogs
-        self.modules_manager.set_max_queue_size(self.max_queue_size)
+        # TOFIX: Beware, the arbiter do not have the max_queue_size property
+        self.modules_manager.set_max_queue_size(getattr(self, 'max_queue_size', 0))
+        # And make the module manager load the sub-process Queue() manager
+        self.modules_manager.load_manager(self.manager)
+
+
 
     def change_to_workdir(self):
+        self.workdir = os.path.abspath(self.workdir)
         try:
             os.chdir(self.workdir)
         except Exception, e:
             raise InvalidWorkDir(e)
         self.debug_output.append("Successfully changed to workdir: %s" % (self.workdir))
 
+
     def unlink(self):
         logger.debug("Unlinking %s" % self.pidfile)
         try:
@@ -297,6 +387,7 @@ class Daemon(object):
         except Exception, e:
             logger.error("Got an error unlinking our pidfile: %s" % (e))
 
+
     # Look if we need a local log or not
     def register_local_log(self):
         # The arbiter doesn't have such attribute
@@ -309,6 +400,7 @@ class Daemon(object):
                 sys.exit(2)
             logger.info("Using the local log file '%s'" % self.local_log)
 
+
     # Only on linux: Check for /dev/shm write access
     def check_shm(self):
         import stat
@@ -320,24 +412,24 @@ class Daemon(object):
                 logger.critical("The directory %s is not writable or readable. Please make it read writable: %s" % (shm_path, shm_path))
                 sys.exit(2)
 
+
     def __open_pidfile(self, write=False):
         ## if problem on opening or creating file it'll be raised to the caller:
         try:
             p = os.path.abspath(self.pidfile)
-            self.debug_output.append("Opening pid file: %s" % self.pidfile)
+            self.debug_output.append("Opening pid file: %s" % p)
             # Windows do not manage the rw+ mode, so we must open in read mode first, then reopen it write mode...
             if not write and os.path.exists(p):
                 self.fpid = open(p, 'r+')
             else:  # If it doesn't exist too, we create it as void
                 self.fpid = open(p, 'w+')
-        except Exception, e:
-            raise InvalidPidFile(e)
+        except Exception as err:
+            raise InvalidPidFile(err)
+
 
     # Check (in pidfile) if there isn't already a daemon running. If yes and do_replace: kill it.
     # Keep in self.fpid the File object to the pidfile. Will be used by writepid.
     def check_parallel_run(self):
-
-
         # TODO: other daemon run on nt
         if os.name == 'nt':
             logger.warning("The parallel daemon check is not available on nt")
@@ -347,31 +439,28 @@ class Daemon(object):
         # First open the pid file in open mode
         self.__open_pidfile()
         try:
-            pid = int(self.fpid.read())
-        except:
-            logger.info("Stale pidfile exists (no or invalid or unreadable content). Reusing it.")
+            pid = int(self.fpid.readline().strip(' \r\n'))
+        except Exception as err:
+            logger.info("Stale pidfile exists at %s (%s). Reusing it." % (err, self.pidfile))
             return
 
         try:
             os.kill(pid, 0)
-        except OverflowError, e:
-            ## pid is too long for "kill": so bad content:
-            logger.error("Stale pidfile exists: pid=%d is too long" % (pid))
+        except Exception as err: # consider any exception as a stale pidfile.
+            # this includes :
+            #  * PermissionError when a process with same pid exists but is executed by another user.
+            #  * ProcessLookupError: [Errno 3] No such process.
+            logger.info("Stale pidfile exists (%s), Reusing it." % err)
             return
-        except os.error, e:
-            if e.errno == errno.ESRCH:
-                logger.info("Stale pidfile exists (pid=%d not exists). Reusing it." % (pid))
-                return
-            raise
 
         if not self.do_replace:
-            raise SystemExit, "valid pidfile exists and not forced to replace.  Exiting."
+            raise SystemExit("valid pidfile exists (pid=%s) and not forced to replace. Exiting." % pid)
 
         self.debug_output.append("Replacing previous instance %d" % pid)
         try:
-            os.kill(pid, 3)
-        except os.error, e:
-            if e.errno != errno.ESRCH:
+            os.kill(pid, signal.SIGQUIT)
+        except os.error as err:
+            if err.errno != errno.ESRCH:
                 raise
 
         self.fpid.close()
@@ -381,6 +470,7 @@ class Daemon(object):
         # because the previous instance should have deleted it!!
         self.__open_pidfile(write=True)
 
+
     def write_pid(self, pid=None):
         if pid is None:
             pid = os.getpid()
@@ -390,6 +480,7 @@ class Daemon(object):
         self.fpid.close()
         del self.fpid  ## no longer needed
 
+
     # Close all the process file descriptors. Skip the descriptors
     # present in the skip_close_fds list
     def close_fds(self, skip_close_fds):
@@ -409,10 +500,10 @@ class Daemon(object):
             except OSError:  # ERROR, fd wasn't open to begin with (ignored)
                 pass
 
+
     # Go in "daemon" mode: close unused fds, redirect stdout/err,
     # chdir, umask, fork-setsid-fork-writepid
     def daemonize(self, skip_close_fds=None):
-
         if skip_close_fds is None:
             skip_close_fds = tuple()
 
@@ -471,6 +562,7 @@ class Daemon(object):
             logger.debug(s)
         del self.debug_output
 
+
     def do_daemon_init_and_start(self, use_pyro=True):
         self.change_to_user_group()
         self.change_to_workdir()
@@ -483,11 +575,11 @@ class Daemon(object):
         # Force the debug level if the daemon is said to start with such level
         if self.debug:
             logger.set_level('DEBUG')
-        
+
         # Then start to log all in the local file if asked so
         self.register_local_log()
         if self.is_daemon:
-            socket_fds = [sock.fileno() for sock in self.pyro_daemon.get_sockets()]
+            socket_fds = [sock.fileno() for sock in self.http_daemon.get_sockets()]
             # Do not close the local_log file too if it's open
             if self.local_log_fd:
                 socket_fds.append(self.local_log_fd)
@@ -502,53 +594,79 @@ class Daemon(object):
         if is_android:
             self.manager = None
         else:
-            self.manager = Manager()
-        # And make the module manager know it
-        self.modules_manager.load_manager(self.manager)
+            # The Manager is a sub-process, so we must be sure it won't have
+            # a socket of your http server alive
+            self.manager = SyncManager(('127.0.0.1',0))
+            def close_http_daemon(daemon):
+                try:
+                    # Be sure to release the lock so there won't be lock in shutdown phase
+                    daemon.lock.release()
+                except Exception, exp:
+                    pass
+                daemon.shutdown()
+            # Some multiprocessing lib got problems with start() that cannot take args
+            # so we must look at it before
+            startargs = inspect.getargspec(self.manager.start)
+            # startargs[0] will be ['self'] if old multiprocessing lib
+            # and ['self', 'initializer', 'initargs'] in newer ones
+            # note: windows do not like pickle http_daemon...
+            if os.name != 'nt' and len(startargs[0]) > 1:
+                self.manager.start(close_http_daemon, initargs=(self.http_daemon,))
+            else:
+                self.manager.start()
+            # Keep this daemon in the http_daemn module
+        # Will be add to the modules manager later
 
+        # Now start the http_daemon thread
+        self.http_thread = None
+        if use_pyro:
+            # Directly acquire it, so the http_thread will wait for us
+            self.http_daemon.lock.acquire()
+            self.http_thread = threading.Thread(None, self.http_daemon_thread, 'http_thread')
+            # Don't lock the main thread just because of the http thread
+            self.http_thread.daemon = True
+            self.http_thread.start()
+
+
+    # TODO: we do not use pyro anymore, change the function name....
     def setup_pyro_daemon(self):
-
         if hasattr(self, 'use_ssl'):  # "common" daemon
             ssl_conf = self
         else:
             ssl_conf = self.conf     # arbiter daemon..
 
+        use_ssl = ssl_conf.use_ssl
+        ca_cert = ssl_cert = ssl_key = ''
+        http_backend = self.http_backend
+
         # The SSL part
-        if ssl_conf.use_ssl:
-            # Maybe this Pyro version do not manage SSL, if so, bailout
-            if not hasattr(Pyro.config, 'PYROSSL_CERTDIR'):
-                logger.error('Sorry, this Pyro version do not manage SSL.')
+        if use_ssl:
+            ssl_cert = os.path.abspath(str(ssl_conf.server_cert))
+            if not os.path.exists(ssl_cert):
+                logger.error('Error : the SSL certificate %s is missing (server_cert). Please fix it in your configuration' % ssl_cert)
                 sys.exit(2)
-            # Protect against name->IP substritution in Pyro3
-            Pyro.config.PYRO_DNS_URI = 1
-            # Beware #839 Pyro lib need str path, not unicode
-            Pyro.config.PYROSSL_CERTDIR = os.path.abspath(str(ssl_conf.certs_dir))
-            if not os.path.exists(Pyro.config.PYROSSL_CERTDIR):
-                logger.error('Error : the directory %s is missing for SSL certificates (certs_dir). Please fix it in your configuration' % Pyro.config.PYROSSL_CERTDIR)
+            ca_cert = os.path.abspath(str(ssl_conf.ca_cert))
+            logger.info("Using ssl ca cert file: %s" % ca_cert)
+            ssl_key = os.path.abspath(str(ssl_conf.server_key))
+            if not os.path.exists(ssl_key):
+                logger.error('Error : the SSL key %s is missing (server_key). Please fix it in your configuration' % ssl_key)
                 sys.exit(2)
-            logger.debug("Using ssl certificate directory: %s" % Pyro.config.PYROSSL_CERTDIR)
-            Pyro.config.PYROSSL_CA_CERT = os.path.abspath(str(ssl_conf.ca_cert))
-            logger.debug("Using ssl ca cert file: %s" % Pyro.config.PYROSSL_CA_CERT)
-            Pyro.config.PYROSSL_CERT = os.path.abspath(str(ssl_conf.server_cert))
-            logger.debug("Using ssl server cert file: %s" % Pyro.config.PYROSSL_CERT)
+            logger.info("Using ssl server cert/key files: %s/%s" % (ssl_cert, ssl_key))
 
             if ssl_conf.hard_ssl_name_check:
-                Pyro.config.PYROSSL_POSTCONNCHECK = 1
-            else:
-                Pyro.config.PYROSSL_POSTCONNCHECK = 0
+                logger.info("Enabling hard SSL server name verification")
 
-        # create the server, but Pyro > 4.8 version
-        # do not have such objects...
-        try:
-            Pyro.config.PYRO_STORAGE = "."
-            Pyro.config.PYRO_COMPRESSION = 1
-            Pyro.config.PYRO_MULTITHREADED = 0
-        except:
-            pass
-
-        self.pyro_daemon = pyro.ShinkenPyroDaemon(self.host, self.port, ssl_conf.use_ssl)
+        # Let's create the HTTPDaemon, it will be exec after
+        self.http_daemon = HTTPDaemon(self.host, self.port, http_backend, use_ssl, ca_cert, ssl_key, ssl_cert, ssl_conf.hard_ssl_name_check, self.daemon_thread_pool_size)
+        http_daemon.daemon_inst = self.http_daemon
 
+    # Global loop part
     def get_socks_activity(self, socks, timeout):
+        # some os are not managing void socks list, so catch this
+        # and just so a simple sleep instead
+        if socks == []:
+            time.sleep(timeout)
+            return []
         try:
             ins, _, _ = select.select(socks, [], [], timeout)
         except select.error, e:
@@ -558,23 +676,24 @@ class Daemon(object):
             raise
         return ins
 
+
     # Find the absolute path of the shinken module directory and returns it.
+    # If the directory do not exist, we must exit!
     def find_modules_path(self):
-        import shinken
-        # BEWARE: this way of finding path is good if we still
-        # DO NOT HAVE CHANGED PWD!!!
-        # Now get the module path. It's in fact the directory modules
-        # inside the shinken directory. So let's find it.
+        if not hasattr(self, 'modules_dir') or not self.modules_dir:
+            logger.error("Your configuration is missing the path to the modules (modules_dir). I set it by default to /var/lib/shinken/modules. Please configure it")
+            self.modules_dir = '/var/lib/shinken/modules'
+        self.modules_dir = os.path.abspath(self.modules_dir)
+        logger.info("Modules directory: %s" % (self.modules_dir))
+        if not os.path.exists(self.modules_dir):
+            logger.error("The modules directory '%s' is missing! Bailing out. Please fix your configuration" % self.modules_dir)
+            raise Exception("The modules directory '%s' is missing! Bailing out. Please fix your configuration" % self.modules_dir)
 
-        self.debug_output.append("modulemanager file %s" % shinken.modulesmanager.__file__)
-        modulespath = os.path.abspath(shinken.modulesmanager.__file__)
-        self.debug_output.append("modulemanager absolute file %s" % modulespath)
-        # We got one of the files
-        parent_path = os.path.dirname(os.path.dirname(modulespath))
-        modulespath = os.path.join(parent_path, 'shinken', 'modules')
-        self.debug_output.append("Using modules path: %s" % (modulespath))
+        # Ok remember to populate the modulesctx object
+        modulesctx.set_modulesdir(self.modules_dir)
+
+        return self.modules_dir
 
-        return modulespath
 
     # modules can have process, and they can die
     def check_and_del_zombie_modules(self):
@@ -584,6 +703,7 @@ class Daemon(object):
         # and try to restart previous dead :)
         self.modules_manager.try_to_restart_deads()
 
+
     # Just give the uid of a user by looking at it's name
     def find_uid_from_name(self):
         try:
@@ -629,7 +749,7 @@ class Daemon(object):
         if uid is None or gid is None:
             logger.error("uid or gid is none. Exiting")
             sys.exit(2)
-            
+
         # Maybe the os module got the initgroups function. If so, try to call it.
         # Do this when we are still root
         if hasattr(os, 'initgroups'):
@@ -646,6 +766,7 @@ class Daemon(object):
             logger.error("cannot change user/group to %s/%s (%s [%d]). Exiting" % (self.user, self.group, e.strerror, e.errno))
             sys.exit(2)
 
+
     # Parse self.config_file and get all properties in it.
     # If some properties need a pythonization, we do it.
     # Also put default value in the properties if some are missing in the config_file
@@ -675,6 +796,7 @@ class Daemon(object):
                 value = entry.pythonize(entry.default)
                 setattr(self, prop, value)
 
+
     # Some paths can be relatives. We must have a full path by taking
     # the config file by reference
     def relative_paths_to_full(self, reference_path):
@@ -690,15 +812,17 @@ class Daemon(object):
                 setattr(self, prop, path)
                 #print "Setting %s for %s" % (path, prop)
 
+
     def manage_signal(self, sig, frame):
         logger.debug("I'm process %d and I received signal %s" % (os.getpid(), str(sig)))
-        if sig == 10:  # if USR1, ask a memory dump
+        if sig == signal.SIGUSR1:  # if USR1, ask a memory dump
             self.need_dump_memory = True
-        elif sig == 12: # if USR2, ask objects dump
+        elif sig == signal.SIGUSR2: # if USR2, ask objects dump
             self.need_objects_dump = True
         else:  # Ok, really ask us to die :)
             self.interrupted = True
 
+
     def set_exit_handler(self):
         func = self.manage_signal
         if os.name == "nt":
@@ -712,58 +836,88 @@ class Daemon(object):
             for sig in (signal.SIGTERM, signal.SIGINT, signal.SIGUSR1, signal.SIGUSR2):
                 signal.signal(sig, func)
 
+
     def get_header(self):
         return ["Shinken %s" % VERSION,
-                "Copyright (c) 2009-2011:",
+                "Copyright (c) 2009-2014:",
                 "Gabes Jean (naparuba@gmail.com)",
                 "Gerhard Lausser, Gerhard.Lausser@consol.de",
                 "Gregory Starck, g.starck@gmail.com",
                 "Hartmut Goebel, h.goebel@goebel-consult.de",
                 "License: AGPL"]
 
+
     def print_header(self):
         for line in self.get_header():
             logger.info(line)
 
-# Wait up to timeout to handle the pyro daemon requests.
-# If suppl_socks is given it also looks for activity on that list of fd.
-# Returns a 3-tuple:
-# If timeout: first arg is 0, second is [], third is possible system time change value
-# If not timeout (== some fd got activity):
-#  - first arg is elapsed time since wait,
-#  - second arg is sublist of suppl_socks that got activity.
-#  - third arg is possible system time change value, or 0 if no change.
-    def handleRequests(self, timeout, suppl_socks=None):
 
+    # Main fonction of the http daemon thread will loop forever unless we stop the root daemon
+    def http_daemon_thread(self):
+        logger.info("Starting HTTP daemon")
+
+        # The main thing is to have a pool of X concurrent requests for the http_daemon,
+        # so "no_lock" calls can always be directly answer without having a "locked" version to
+        # finish
+        print "GO FOR IT"
+        try:
+            self.http_daemon.run()
+        except Exception, exp:
+            logger.error('The HTTP daemon failed with the error %s, exiting' % str(exp))
+            output = cStringIO.StringIO()
+            traceback.print_exc(file=output)
+            logger.error("Back trace of this error: %s" % (output.getvalue()))
+            output.close()
+            self.do_stop()
+            # Hard mode exit from a thread
+            os._exit(2)
+
+
+    # Wait up to timeout to handle the pyro daemon requests.
+    # If suppl_socks is given it also looks for activity on that list of fd.
+    # Returns a 3-tuple:
+    # If timeout: first arg is 0, second is [], third is possible system time change value
+    # If not timeout (== some fd got activity):
+    #  - first arg is elapsed time since wait,
+    #  - second arg is sublist of suppl_socks that got activity.
+    #  - third arg is possible system time change value, or 0 if no change.
+    def handleRequests(self, timeout, suppl_socks=None):
         if suppl_socks is None:
             suppl_socks = []
         before = time.time()
-        socks = self.pyro_daemon.get_sockets()
+        socks = []
         if suppl_socks:
             socks.extend(suppl_socks)
+        # Release the lock so the http_thread can manage request during we are waiting
+        if self.http_daemon:
+            self.http_daemon.lock.release()
+        # Ok give me the socks taht moved during the timeout max
         ins = self.get_socks_activity(socks, timeout)
+        # Ok now get back the global lock!
+        if self.http_daemon:
+            self.http_daemon.lock.acquire()
         tcdiff = self.check_for_system_time_change()
         before += tcdiff
         # Increase our sleep time for the time go in select
         self.sleep_time += time.time() - before
         if len(ins) == 0:  # trivial case: no fd activity:
             return 0, [], tcdiff
-        for sock in socks:
-            if sock in ins and sock not in suppl_socks:
-                self.pyro_daemon.handleRequests(sock)
-                ins.remove(sock)
-        # Tack in elapsed the WHOLE time, even with handling requests
+        # HERE WAS THE HTTP, but now it's managed in an other thread
+        #for sock in socks:
+        #    if sock in ins and sock not in suppl_socks:
+        #        ins.remove(sock)
+        # Track in elapsed the WHOLE time, even with handling requests
         elapsed = time.time() - before
         if elapsed == 0:  # we have done a few instructions in 0 second exactly!? quantum computer?
             elapsed = 0.01  # but we absolutely need to return!= 0 to indicate that we got activity
         return elapsed, ins, tcdiff
 
+
     # Check for a possible system time change and act correspondingly.
     # If such a change is detected then we return the number of seconds that changed. 0 if no time change was detected.
     # Time change can be positive or negative:
     # positive when we have been sent in the future and negative if we have been sent in the past.
     def check_for_system_time_change(self):
-
         now = time.time()
         difference = now - self.t_each_loop
 
@@ -777,12 +931,14 @@ class Daemon(object):
 
         return difference
 
+
     # Default action for system time change. Actually a log is done
     def compensate_system_time_change(self, difference):
         logger.warning('A system time change of %s has been detected.  Compensating...' % difference)
 
+
     # Use to wait conf from arbiter.
-    # It send us conf in our pyro_daemon. It put the have_conf prop
+    # It send us conf in our http_daemon. It put the have_conf prop
     # if he send us something
     # (it can just do a ping)
     def wait_for_initial_conf(self, timeout=1.0):
@@ -799,6 +955,7 @@ class Daemon(object):
             sys.stdout.write(".")
             sys.stdout.flush()
 
+
     # We call the function of modules that got the this
     # hook function
     def hook_point(self, hook_name):
@@ -812,11 +969,13 @@ class Daemon(object):
                     logger.warning('The instance %s raised an exception %s. I disabled it, and set it to restart later' % (inst.get_name(), str(exp)))
                     self.modules_manager.set_to_restart(inst)
 
+
     # Dummy function for daemons. Get all retention data
     # So a module can save them
     def get_retention_data(self):
         return []
 
+
     # Save, to get back all data
     def restore_retention_data(self, data):
         pass
