@@ -32,6 +32,8 @@ import socket
 import traceback
 import cStringIO
 import cPickle
+import copy
+import json
 
 from shinken.objects.config import Config
 from shinken.external_command import ExternalCommandManager
@@ -40,29 +42,42 @@ from shinken.daemon import Daemon, Interface
 from shinken.log import logger
 from shinken.brok import Brok
 from shinken.external_command import ExternalCommand
-
+from shinken.util import jsonify_r
 
 # Interface for the other Arbiter
 # It connects, and together we decide who's the Master and who's the Slave, etc.
 # Here is a also a function to get a new conf from the master
 class IForArbiter(Interface):
-
+    
+    doc = 'Does the daemon got a configuration (internal)'
     def have_conf(self, magic_hash):
+        # Beware, we got an str in entry, not an int
+        magic_hash = int(magic_hash)
         # I've got a conf and a good one
         if self.app.cur_conf and self.app.cur_conf.magic_hash == magic_hash:
             return True
         else:  # I've no conf or a bad one
             return False
+    have_conf.doc = doc
 
+    
+    doc = 'Put a new configuration to the daemon'
     # The master Arbiter is sending us a new conf in a pickle way. Ok, we take it
-    def put_conf(self, conf_raw):
-        conf = cPickle.loads(conf_raw)
+    def put_conf(self, conf):
+        conf = cPickle.loads(conf)
         super(IForArbiter, self).put_conf(conf)
         self.app.must_run = False
+    put_conf.method = 'POST'
+    put_conf.doc = doc
 
+
+    doc = 'Get the managed configuration (internal)'
     def get_config(self):
         return self.app.conf
+    get_config.doc = doc
 
+
+    doc = 'Ask the daemon to do not run'
     # The master arbiter asks me not to run!
     def do_not_run(self):
         # If I'm the master, ignore the command
@@ -73,61 +88,79 @@ class IForArbiter(Interface):
             logger.debug("Received message to not run. I am the spare, stopping.")
             self.app.last_master_speack = time.time()
             self.app.must_run = False
+    do_not_run.need_lock = False
+    do_not_run.doc = doc
 
-    # Here a function called by check_shinken to get daemon status
-    def get_satellite_status(self, daemon_type, daemon_name):
-        daemon_name_attr = daemon_type + "_name"
-        daemons = self.app.get_daemons(daemon_type)
-        if daemons:
-            for dae in daemons:
-                if hasattr(dae, daemon_name_attr) and getattr(dae, daemon_name_attr) == daemon_name:
-                    if hasattr(dae, 'alive') and hasattr(dae, 'spare'):
-                        return {'alive': dae.alive, 'spare': dae.spare}
-        return None
 
+    doc = 'Get the satellite names sort by type'
     # Here a function called by check_shinken to get daemons list
-    def get_satellite_list(self, daemon_type):
-        satellite_list = []
-        daemon_name_attr = daemon_type + "_name"
-        daemons = self.app.get_daemons(daemon_type)
-        if daemons:
+    def get_satellite_list(self, daemon_type=''):
+        res = {}
+        for t in ['arbiter', 'scheduler', 'poller', 'reactionner', 'receiver',
+                  'broker']:
+            if daemon_type and daemon_type != t:
+                continue
+            satellite_list = []
+            res[t] = satellite_list
+            daemon_name_attr = t + "_name"
+            daemons = self.app.get_daemons(t)
             for dae in daemons:
                 if hasattr(dae, daemon_name_attr):
                     satellite_list.append(getattr(dae, daemon_name_attr))
-                else:
-                    # If one daemon has no name... ouch!
-                    return None
-            return satellite_list
-        return None
+        return res
+    get_satellite_list.doc = doc
 
+
+    doc = 'Dummy call for the arbiter'
     # Dummy call. We are the master, we manage what we want
     def what_i_managed(self):
         return {}
+    what_i_managed.need_lock = False
+    what_i_managed.doc = doc
 
+    
+    doc = 'Return all the data of the satellites'
+    # We will try to export all data from our satellites, but only the json-able fields
     def get_all_states(self):
-        res = {'arbiter': self.app.conf.arbiters,
-               'scheduler': self.app.conf.schedulers,
-               'poller': self.app.conf.pollers,
-               'reactionner': self.app.conf.reactionners,
-               'receiver': self.app.conf.receivers,
-               'broker': self.app.conf.brokers}
-        return res
-
+        res = {}
+        for t in ['arbiter', 'scheduler', 'poller', 'reactionner', 'receiver',
+                  'broker']:
+            lst = []
+            res[t] = lst
+            for d in getattr(self.app.conf, t+'s'):
+                cls = d.__class__
+                e = {}
+                ds = [cls.properties, cls.running_properties]
+                for _d in ds:
+                    for prop in _d:
+                        if hasattr(d, prop):
+                            v = getattr(d, prop)
+                            # give a try to a json able object
+                            try:
+                                json.dumps(v)
+                                e[prop] = v
+                            except Exception, exp:
+                                print exp
+                    lst.append(e)
+                        
+        return lst
+    get_all_states.doc = doc
+    
+    
     # Try to give some properties of our objects
-    def get_objects_properties(self, table, *properties):
-        logger.debug('ASK:: table= %s, properties= %s' % (str(table), str(properties)))
+    doc = 'Dump all objects of the type in [hosts, services, contacts, commands, hostgroups, servicegroups]'
+    def get_objects_properties(self, table):
+        logger.debug('ASK:: table= %s' % str(table))
         objs = getattr(self.app.conf, table, None)
         logger.debug("OBJS:: %s" % str(objs))
-        if not objs:
-            return ''
+        if objs is None or len(objs) == 0:
+            return []
         res = []
         for obj in objs:
-            l = []
-            for prop in properties:
-                v = getattr(obj, prop, '')
-                l.append(v)
+            l = jsonify_r(obj)
             res.append(l)
         return res
+    get_objects_properties.doc = doc
 
 
 # Main Arbiter Class
@@ -161,6 +194,7 @@ class Arbiter(Daemon):
         self.conf = Config()
 
 
+
     # Use for adding things like broks
     def add(self, b):
         if isinstance(b, Brok):
@@ -219,15 +253,18 @@ class Arbiter(Daemon):
                 b = s.get_initial_status_brok()
                 self.add(b)
 
+
     # Load the external commander
     def load_external_command(self, e):
         self.external_command = e
         self.fifo = e.open()
 
+
     def get_daemon_links(self, daemon_type):
         # the attribute name to get these differs for schedulers and arbiters
         return daemon_type + 's'
 
+
     def load_config_file(self):
         logger.info("Loading configuration")
         # REF: doc/shinken-conf-dispatching.png (1)
@@ -268,6 +305,10 @@ class Arbiter(Daemon):
 
         logger.info("My own modules: " + ','.join([m.get_name() for m in self.me.modules]))
 
+        self.modules_dir = getattr(self.conf, 'modules_dir', '')
+
+        # Ok it's time to load the module manager now!
+        self.load_modules_manager()
         # we request the instances without them being *started*
         # (for those that are concerned ("external" modules):
         # we will *start* these instances after we have been daemonized (if requested)
@@ -280,6 +321,7 @@ class Arbiter(Daemon):
         # Now we ask for configuration modules if they
         # got items for us
         for inst in self.modules_manager.instances:
+            #TODO : clean
             if 'configuration' in inst.phases:
                 try:
                     r = inst.get_objects()
@@ -355,9 +397,20 @@ class Arbiter(Daemon):
         # search lists
         self.conf.create_reversed_list()
 
+        # Overrides sepecific service instaces properties
+        self.conf.override_properties()
+
         # Pythonize values
         self.conf.pythonize()
 
+        # Removes service exceptions based on host configuration
+        count = self.conf.remove_exclusions()
+
+        if count > 0:
+            # We removed excluded services, and so we must recompute the
+            # search lists
+            self.conf.create_reversed_list()
+
         # Linkify objects to each other
         self.conf.linkify()
 
@@ -395,6 +448,9 @@ class Arbiter(Daemon):
         # Correct conf?
         self.conf.is_correct()
 
+        # Maybe some elements where not wrong, so we must clean if possible
+        self.conf.clean()
+
         # If the conf is not correct, we must get out now
         # if not self.conf.conf_is_correct:
         #    sys.exit("Configuration is incorrect, sorry, I bail out")
@@ -439,6 +495,8 @@ class Arbiter(Daemon):
         self.user = self.conf.shinken_user
         self.group = self.conf.shinken_group
         self.daemon_enabled = self.conf.daemon_enabled
+        self.daemon_thread_pool_size = self.conf.daemon_thread_pool_size
+        self.http_backend = getattr(self.conf, 'http_backend', 'auto')
 
         # If the user sets a workdir, lets use it. If not, use the
         # pidfile directory
@@ -490,7 +548,7 @@ class Arbiter(Daemon):
         print "***********"*5
         print "WARNING : this feature is NOT supported in this version!"
         print "***********"*5
-        
+
         migration_module_name = self.migrate.strip()
         mig_mod = self.conf.modules.find_by_name(migration_module_name)
         if not mig_mod:
@@ -524,7 +582,7 @@ class Arbiter(Daemon):
             f(objs)
         # Ok we can exit now
         sys.exit(0)
-        
+
 
 
     # Main loop function
@@ -539,12 +597,12 @@ class Arbiter(Daemon):
             # Maybe we are in a migration phase. If so, we will bailout here
             if self.migrate:
                 self.go_migrate()
-                
+
             # Look if we are enabled or not. If ok, start the daemon mode
             self.look_for_early_exit()
             self.do_daemon_init_and_start()
-            
-            self.uri_arb = self.pyro_daemon.register(self.interface, "ForArbiter")
+
+            self.uri_arb = self.http_daemon.register(self.interface)#, "ForArbiter")
 
             # ok we are now fully daemonized (if requested)
             # now we can start our "external" modules (if any):
@@ -565,6 +623,7 @@ class Arbiter(Daemon):
             logger.critical("Exception trace follows: %s" % (traceback.format_exc()))
             raise
 
+
     def setup_new_conf(self):
         """ Setup a new conf received from a Master arbiter. """
         conf = self.new_conf
@@ -705,7 +764,6 @@ class Arbiter(Daemon):
         timeout = 1.0
 
         while self.must_run and not self.interrupted:
-
             elapsed, ins, _ = self.handleRequests(timeout, suppl_socks)
 
             # If FIFO, read external command
