@@ -39,5 +39,5 @@ class Poller(Satellite):
         'local_log': PathProp(default='pollerd.log'),
     })
 
-    def __init__(self, config_file, is_daemon, do_replace, debug, debug_file):
+    def __init__(self, config_file, is_daemon, do_replace, debug, debug_file, profile):
         super(Poller, self).__init__('poller', config_file, is_daemon, do_replace, debug, debug_file)
