@@ -26,13 +26,14 @@
 import os
 import time
 
-from shinken.util import to_int, to_bool
+from shinken.util import to_int, to_bool, split_semicolon
 from shinken.downtime import Downtime
 from shinken.contactdowntime import ContactDowntime
 from shinken.comment import Comment
 from shinken.commandcall import CommandCall
 from shinken.log import logger, console_logger
 from shinken.pollerlink import PollerLink
+from shinken.eventhandler import EventHandler
 
 MODATTR_NONE = 0
 MODATTR_NOTIFICATIONS_ENABLED = 1
@@ -192,7 +193,7 @@ class ExternalCommandManager:
         'READ_STATE_INFORMATION': {'global': True, 'args': []},
         'REMOVE_HOST_ACKNOWLEDGEMENT': {'global': False, 'args': ['host']},
         'REMOVE_SVC_ACKNOWLEDGEMENT': {'global': False, 'args': ['service']},
-        'RESTART_PROGRAM': {'global': True, 'args': []},
+        'RESTART_PROGRAM': {'global': True, 'internal': True, 'args': []},
         'SAVE_STATE_INFORMATION': {'global': True, 'args': []},
         'SCHEDULE_AND_PROPAGATE_HOST_DOWNTIME': {'global': False, 'args': ['host', 'to_int', 'to_int', 'to_bool', 'to_int', 'to_int', 'author', None]},
         'SCHEDULE_AND_PROPAGATE_TRIGGERED_HOST_DOWNTIME': {'global': False, 'args': ['host', 'to_int', 'to_int', 'to_bool', 'to_int', 'to_int', 'author', None]},
@@ -392,7 +393,7 @@ class ExternalCommandManager:
     def get_command_and_args(self, command, extcmd=None):
         #safe_print("Trying to resolve", command)
         command = command.rstrip()
-        elts = command.split(';')  # danger!!! passive checkresults with perfdata
+        elts = split_semicolon(command)  # danger!!! passive checkresults with perfdata
         part1 = elts[0]
 
         elts2 = part1.split(' ')
@@ -408,7 +409,7 @@ class ExternalCommandManager:
         # Ok we remove the [ ]
         ts = ts[1:-1]
         try:  # is an int or not?
-            self.current_timestamp = int(ts)
+            self.current_timestamp = to_int(ts)
         except ValueError:
             logger.debug("Malformed command '%s'" % command)
             return None
@@ -434,7 +435,7 @@ class ExternalCommandManager:
         numargs = len(entry['args'])
         if numargs and 'service' in entry['args']:
             numargs += 1
-        elts = command.split(';', numargs)
+        elts = split_semicolon(command, numargs)
 
         logger.debug("mode= %s, global= %s" % (self.mode, str(entry['global'])))
         if self.mode == 'dispatcher' and entry['global']:
@@ -1374,7 +1375,28 @@ class ExternalCommandManager:
 
     # RESTART_PROGRAM
     def RESTART_PROGRAM(self):
-        pass
+        restart_cmd = self.commands.find_by_name('restart_shinken')
+        if not restart_cmd:
+            console_logger.error("Cannot restart Shinken : missing command named 'restart_shinken'. Please add one")
+            return
+        restart_cmd_line = restart_cmd.command_line
+        
+        # Ok get an event handler command that will run in 15min max
+        e = EventHandler(restart_cmd_line, timeout=900)
+        # Ok now run it
+        e.execute()
+        # And wait for the command to finish
+        while not e.status in ('done', 'timeout'):
+            e.check_finished(64000)
+        if e.status == 'timeout' or e.exit_status != 0:
+            console_logger.error("Cannot restart Shinken : the 'restart_shinken' command failed with the error code '%d' and the text '%s'." % (e.exit_status, e.output))
+            return
+        # Ok here the command succeed, we can now wait our death
+        console_logger.info("%s\%s" % (e.output, e.long_output))
+        console_logger.info("RESTART command launched. Waiting for the new daemon to kill us")
+        
+        
+        
 
     # SAVE_STATE_INFORMATION
     def SAVE_STATE_INFORMATION(self):
