@@ -27,7 +27,9 @@ import re
 from shinken.util import to_best_int_float
 
 perfdata_split_pattern = re.compile('([^=]+=\S+)')
-metric_pattern = re.compile('^([^=]+)=([\d\.\-eE]+)([\w\/%]*);?([\d\.\-eE:~@]+)?;?([\d\.\-eE:~@]+)?;?([\d\.\-eE]+)?;?([\d\.\-eE]+)?;?\s*')
+# TODO: Improve this regex to not match strings like this:
+# 'metric=45+e-456.56unit;50;80;0;45+-e45e-'
+metric_pattern = re.compile('^([^=]+)=([\d\.\-\+eE]+)([\w\/%]*);?([\d\.\-\+eE:~@]+)?;?([\d\.\-\+eE:~@]+)?;?([\d\.\-\+eE]+)?;?([\d\.\-\+eE]+)?;?\s*')
 
 
 # If we can return an int or a float, or None
