@@ -28,10 +28,14 @@ import time
 import sys
 import traceback
 import cStringIO
+import imp
 
 from shinken.basemodule import BaseModule
 from shinken.log import logger
 
+# We need to manage pre-2.0 module types with _ into the new 2.0 - mode
+def uniform_module_type(s):
+    return s.replace('_', '-')
 
 class ModulesManager(object):
     """This class is use to manage modules and call callback"""
@@ -40,7 +44,7 @@ class ModulesManager(object):
         self.modules_path = modules_path
         self.modules_type = modules_type
         self.modules = modules
-        self.allowed_types = [plug.module_type for plug in modules]
+        self.allowed_types = [uniform_module_type(plug.module_type) for plug in modules]
         self.imported_modules = []
         self.modules_assoc = []
         self.instances = []
@@ -48,29 +52,34 @@ class ModulesManager(object):
         self.max_queue_size = 0
         self.manager = None
 
+
     def load_manager(self, manager):
         self.manager = manager
 
+
     # Set the modules requested for this manager
     def set_modules(self, modules):
         self.modules = modules
-        self.allowed_types = [mod.module_type for mod in modules]
+        self.allowed_types = [uniform_module_type(mod.module_type) for mod in modules]
+
 
     def set_max_queue_size(self, max_queue_size):
         self.max_queue_size = max_queue_size
 
+
     # Import, instanciate & "init" the modules we have been requested
     def load_and_init(self):
         self.load()
         self.get_instances()
 
+
     # Try to import the requested modules ; put the imported modules in self.imported_modules.
     # The previous imported modules, if any, are cleaned before.
     def load(self):
         now = int(time.time())
         # We get all modules file with .py
-        modules_files = [fname[:-3] for fname in os.listdir(self.modules_path)
-                         if fname.endswith(".py")]
+        modules_files = []#fname[:-3] for fname in os.listdir(self.modules_path)
+                         #if fname.endswith(".py")]
 
         # And directories
         modules_files.extend([fname for fname in os.listdir(self.modules_path)
@@ -85,24 +94,41 @@ class ModulesManager(object):
         # our type
         del self.imported_modules[:]
         for fname in modules_files:
-            #print "Try to load", fname
             try:
-                m = __import__(fname)
+                # Then we load the module.py inside this directory
+                mod_file = os.path.abspath(os.path.join(self.modules_path, fname,'module.py'))
+                mod_dir  =  os.path.dirname(mod_file)
+                # We add this dir to sys.path so the module can load local files too
+                sys.path.append(mod_dir)
+                if not os.path.exists(mod_file):
+                    mod_file = os.path.abspath(os.path.join(self.modules_path, fname,'module.pyc'))
+                m = None
+                if mod_file.endswith('.py'):
+                    # important, equivalent to import fname from module.py
+                    m = imp.load_source(fname, mod_file)
+                else:
+                    m = imp.load_compiled(fname, mod_file)
+                m_dir = os.path.abspath(os.path.dirname(m.__file__))
+                
+                # Look if it's a valid module
                 if not hasattr(m, 'properties'):
+                    logger.warning('Bad module file for %s : missing properties dict' % mod_file)
                     continue
-
+                
                 # We want to keep only the modules of our type
                 if self.modules_type in m.properties['daemons']:
                     self.imported_modules.append(m)
             except Exception, exp:
+                # Oups, somethign went wrong here...
                 logger.warning("Importing module %s: %s" % (fname, exp))
 
+        # Now we want to find in theses modules the ones we are looking for
         del self.modules_assoc[:]
         for mod_conf in self.modules:
-            module_type = mod_conf.module_type
+            module_type = uniform_module_type(mod_conf.module_type)
             is_find = False
             for module in self.imported_modules:
-                if module.properties['type'] == module_type:
+                if uniform_module_type(module.properties['type']) == module_type:
                     self.modules_assoc.append((mod_conf, module))
                     is_find = True
                     break
@@ -110,6 +136,7 @@ class ModulesManager(object):
                 # No module is suitable, we Raise a Warning
                 logger.warning("The module type %s for %s was not found in modules!" % (module_type, mod_conf.get_name()))
 
+
     # Try to "init" the given module instance.
     # If late_start, don't look for last_init_try
     # Returns: True on successful init. False if instance init method raised any Exception.
@@ -138,6 +165,7 @@ class ModulesManager(object):
             return False
         return True
 
+
     # Request to "remove" the given instances list or all if not provided
     def clear_instances(self, insts=None):
         if insts is None:
@@ -145,10 +173,12 @@ class ModulesManager(object):
         for i in insts:
             self.remove_instance(i)
 
+
     # Put an instance to the restart queue
     def set_to_restart(self, inst):
         self.to_restart.append(inst)
 
+
     # actually only arbiter call this method with start_external=False..
     # Create, init and then returns the list of module instances that the caller needs.
     # If an instance can't be created or init'ed then only log is done.
@@ -185,6 +215,7 @@ class ModulesManager(object):
 
         return self.instances
 
+
     # Launch external instances that are load correctly
     def start_external_instances(self, late_start=False):
         for inst in [inst for inst in self.instances if inst.is_external]:
@@ -198,10 +229,10 @@ class ModulesManager(object):
             logger.info("Starting external module %s" % inst.get_name())
             inst.start()
 
+
     # Request to cleanly remove the given instance.
     # If instance is external also shutdown it cleanly
     def remove_instance(self, inst):
-
         # External instances need to be close before (process + queues)
         if inst.is_external:
             logger.debug("Ask stop process for %s" % inst.get_name())
@@ -213,6 +244,7 @@ class ModulesManager(object):
         # Then do not listen anymore about it
         self.instances.remove(inst)
 
+
     def check_alive_instances(self):
         # Only for external
         for inst in self.instances:
@@ -244,6 +276,7 @@ class ModulesManager(object):
                     inst.clear_queues(self.manager)
                     self.to_restart.append(inst)
 
+
     def try_to_restart_deads(self):
         to_restart = self.to_restart[:]
         del self.to_restart[:]
@@ -258,19 +291,24 @@ class ModulesManager(object):
             else:
                 self.to_restart.append(inst)
 
+
     # Do not give to others inst that got problems
     def get_internal_instances(self, phase=None):
         return [inst for inst in self.instances if not inst.is_external and phase in inst.phases and inst not in self.to_restart]
 
+
     def get_external_instances(self, phase=None):
         return [inst for inst in self.instances if inst.is_external and phase in inst.phases and inst not in self.to_restart]
 
+
     def get_external_to_queues(self):
         return [inst.to_q for inst in self.instances if inst.is_external and inst not in self.to_restart]
 
+
     def get_external_from_queues(self):
         return [inst.from_q for inst in self.instances if inst.is_external and inst not in self.to_restart]
 
+
     def stop_all(self):
         # Ask internal to quit if they can
         for inst in self.get_internal_instances():
