@@ -53,6 +53,8 @@ from module import Module, Modules
 from discoveryrule import Discoveryrule, Discoveryrules
 from discoveryrun import Discoveryrun, Discoveryruns
 from trigger import Trigger, Triggers
+from businessimpactmodulation import Businessimpactmodulation,Businessimpactmodulations
+from macromodulation import MacroModulation, MacroModulations
 
 #from config import Config
 
