@@ -35,7 +35,7 @@ from item import Items
 from schedulingitem import SchedulingItem
 
 from shinken.autoslots import AutoSlots
-from shinken.util import format_t_into_dhms_format, to_hostnames_list, get_obj_name, to_svc_hst_distinct_lists, to_list_string_of_names, to_list_of_names, to_name_if_possible
+from shinken.util import format_t_into_dhms_format, to_hostnames_list, get_obj_name, to_svc_hst_distinct_lists, to_list_string_of_names, to_list_of_names, to_name_if_possible, strip_and_uniq
 from shinken.property import BoolProp, IntegerProp, FloatProp, CharProp, StringProp, ListProp
 from shinken.graph import Graph
 from shinken.macroresolver import MacroResolver
@@ -69,11 +69,11 @@ class Host(SchedulingItem):
         'alias':                StringProp(fill_brok=['full_status']),
         'display_name':         StringProp(default='', fill_brok=['full_status']),
         'address':              StringProp(fill_brok=['full_status']),
-        'parents':              ListProp(brok_transformation=to_hostnames_list, default='', fill_brok=['full_status']),
-        'hostgroups':           StringProp(brok_transformation=to_list_string_of_names, default='', fill_brok=['full_status']),
+        'parents':              ListProp(brok_transformation=to_hostnames_list, default='', fill_brok=['full_status'], merging='join'),
+        'hostgroups':           StringProp(brok_transformation=to_list_string_of_names, default='', fill_brok=['full_status'], merging='join'),
         'check_command':        StringProp(default='_internal_host_up', fill_brok=['full_status']),
         'initial_state':        CharProp(default='u', fill_brok=['full_status']),
-        'max_check_attempts':   IntegerProp(fill_brok=['full_status']),
+        'max_check_attempts':   IntegerProp(default='1',fill_brok=['full_status']),
         'check_interval':       IntegerProp(default='0', fill_brok=['full_status']),
         'retry_interval':       IntegerProp(default='0', fill_brok=['full_status']),
         'active_checks_enabled': BoolProp(default='1', fill_brok=['full_status'], retention=True),
@@ -87,16 +87,16 @@ class Host(SchedulingItem):
         'low_flap_threshold':   IntegerProp(default='25', fill_brok=['full_status']),
         'high_flap_threshold':  IntegerProp(default='50', fill_brok=['full_status']),
         'flap_detection_enabled': BoolProp(default='1', fill_brok=['full_status'], retention=True),
-        'flap_detection_options': ListProp(default='o,d,u', fill_brok=['full_status']),
+        'flap_detection_options': ListProp(default='o,d,u', fill_brok=['full_status'], merging='join'),
         'process_perf_data':    BoolProp(default='1', fill_brok=['full_status'], retention=True),
         'retain_status_information': BoolProp(default='1', fill_brok=['full_status']),
         'retain_nonstatus_information': BoolProp(default='1', fill_brok=['full_status']),
-        'contacts':             StringProp(default='', brok_transformation=to_list_of_names, fill_brok=['full_status']),
-        'contact_groups':       StringProp(default='', fill_brok=['full_status']),
+        'contacts':             StringProp(default='', brok_transformation=to_list_of_names, fill_brok=['full_status'], merging='join'),
+        'contact_groups':       StringProp(default='', fill_brok=['full_status'], merging='join'),
         'notification_interval': IntegerProp(default='60', fill_brok=['full_status']),
         'first_notification_delay': IntegerProp(default='0', fill_brok=['full_status']),
         'notification_period':  StringProp(brok_transformation=to_name_if_possible, fill_brok=['full_status']),
-        'notification_options': ListProp(default='d,u,r,f', fill_brok=['full_status']),
+        'notification_options': ListProp(default='d,u,r,f', fill_brok=['full_status'], merging='join'),
         'notifications_enabled': BoolProp(default='1', fill_brok=['full_status'], retention=True),
         'stalking_options':     ListProp(default='', fill_brok=['full_status']),
         'notes':                StringProp(default='', fill_brok=['full_status']),
@@ -120,11 +120,25 @@ class Host(SchedulingItem):
         'realm':                StringProp(default=None, fill_brok=['full_status'], conf_send_preparation=get_obj_name),
         'poller_tag':           StringProp(default='None'),
         'reactionner_tag':      StringProp(default='None'),
-        'resultmodulations':    StringProp(default=''),
-        'business_impact_modulations': StringProp(default=''),
-        'escalations':          StringProp(default='', fill_brok=['full_status']),
+        'resultmodulations':    StringProp(default='', merging='join'),
+        'business_impact_modulations': StringProp(default='', merging='join'),
+        'escalations':          StringProp(default='', fill_brok=['full_status'], merging='join'),
         'maintenance_period':   StringProp(default='', brok_transformation=to_name_if_possible, fill_brok=['full_status']),
-        'time_to_orphanage': IntegerProp(default='300', fill_brok=['full_status']),
+        'time_to_orphanage':    IntegerProp(default='300', fill_brok=['full_status']),
+        'service_overrides':    ListProp(default='', merging='duplicate', split_on_coma=False),
+        'service_excludes':     ListProp(default='', merging='duplicate'),
+        'labels':               ListProp(default='', fill_brok=['full_status'], merging='join'),
+
+        # BUSINESS CORRELATOR PART
+        # Business rules output format template
+        'business_rule_output_template': StringProp(default='', fill_brok=['full_status']),
+        # Business rules notifications mode
+        'business_rule_smart_notifications': BoolProp(default='0', fill_brok=['full_status']),
+        # Treat downtimes as acknowledgements in smart notifications
+        'business_rule_downtime_as_ack': BoolProp(default='0', fill_brok=['full_status']),
+        # Enforces child nodes notification options
+        'business_rule_host_notification_options':    ListProp(default='', fill_brok=['full_status']),
+        'business_rule_service_notification_options': ListProp(default='', fill_brok=['full_status']),
 
         # Business impact value
         'business_impact':      IntegerProp(default='2', fill_brok=['full_status']),
@@ -132,17 +146,17 @@ class Host(SchedulingItem):
         # Load some triggers
         'trigger':         StringProp(default=''),
         'trigger_name':    ListProp(default=''),
+        'trigger_broker_raise_enabled': BoolProp(default='0'),
 
         # Trending
-        'trending_policies':    ListProp(default='', fill_brok=['full_status']),
+        'trending_policies':    ListProp(default='', fill_brok=['full_status'], merging='join'),
 
         # Our modulations. By defualt void, but will filled by an inner if need
-        'checkmodulations':       ListProp(default='', fill_brok=['full_status']),
-        'macromodulations':       ListProp(default=''),
+        'checkmodulations':       ListProp(default='', fill_brok=['full_status'], merging='join'),
+        'macromodulations':       ListProp(default='', merging='join'),
 
         # Custom views
-        'custom_views'     :    ListProp(default='', fill_brok=['full_status']),
-
+        'custom_views'     :    ListProp(default='', fill_brok=['full_status'], merging='join'),
     })
 
     # properties set only for running purpose
@@ -153,6 +167,7 @@ class Host(SchedulingItem):
         'last_chk':             IntegerProp(default=0, fill_brok=['full_status', 'check_result'], retention=True),
         'next_chk':             IntegerProp(default=0, fill_brok=['full_status', 'next_schedule'], retention=True),
         'in_checking':          BoolProp(default=False, fill_brok=['full_status', 'check_result', 'next_schedule']),
+        'in_maintenance':       IntegerProp(default=None, fill_brok=['full_status'], retention=True),
         'latency':              FloatProp(default=0, fill_brok=['full_status', 'check_result'], retention=True),
         'attempt':              IntegerProp(default=0, fill_brok=['full_status', 'check_result'], retention=True),
         'state':                StringProp(default='PENDING', fill_brok=['full_status', 'check_result'], retention=True),
@@ -211,6 +226,8 @@ class Host(SchedulingItem):
         'last_problem_id':      IntegerProp(default=0, fill_brok=['full_status', 'check_result'], retention=True),
         'current_problem_id':   IntegerProp(default=0, fill_brok=['full_status', 'check_result'], retention=True),
         'execution_time':       FloatProp(default=0.0, fill_brok=['full_status', 'check_result'], retention=True),
+        'u_time':               FloatProp(default=0.0),
+        's_time':               FloatProp(default=0.0),
         'last_notification':    FloatProp(default=0.0, fill_brok=['full_status'], retention=True),
         'current_notification_number': IntegerProp(default=0, fill_brok=['full_status'], retention=True),
         'current_notification_id': IntegerProp(default=0, fill_brok=['full_status'], retention=True),
@@ -281,6 +298,8 @@ class Host(SchedulingItem):
         # BUSINESS CORRELATOR PART
         # Say if we are business based rule or not
         'got_business_rule': BoolProp(default=False, fill_brok=['full_status']),
+        # Previously processed business rule (with macro expanded)
+        'processed_business_rule': StringProp(default="", fill_brok=['full_status']),
         # Our Dependency node for the business rule
         'business_rule': StringProp(default=None),
 
@@ -343,7 +362,7 @@ class Host(SchedulingItem):
         'HOSTACTIONURL':     'action_url',
         'HOSTNOTESURL':      'notes_url',
         'HOSTNOTES':         'notes',
-        'HOSTREALM':         'get_realm', 
+        'HOSTREALM':         'get_realm',
         'TOTALHOSTSERVICES': 'get_total_services',
         'TOTALHOSTSERVICESOK': 'get_total_services_ok',
         'TOTALHOSTSERVICESWARNING': 'get_total_services_warning',
@@ -434,7 +453,7 @@ class Host(SchedulingItem):
                 state = False
             if self.got_business_rule:
                 if not self.business_rule.is_valid():
-                    logger.info("%s: my business rule is invalid" % (self.get_name(),))
+                    logger.error("%s: my business rule is invalid" % (self.get_name(),))
                     for bperror in self.business_rule.configuration_errors:
                         logger.error("[host::%s] %s" % (self.get_name(), bperror))
                     state = False
@@ -447,7 +466,7 @@ class Host(SchedulingItem):
         if (getattr(self, 'active_checks_enabled', False)
              and getattr(self, 'check_period', None) is None
              and getattr(self, 'check_interval', 1) != 0):
-            logger.info("%s: My check_period is not correct" % self.get_name())
+            logger.info("%s: check_period is not correct" % self.get_name())
             state = False
 
         if not hasattr(self, 'check_period'):
@@ -481,6 +500,24 @@ class Host(SchedulingItem):
             except AttributeError:  # outch, no name for this template
                 return 'UNNAMEDHOSTTEMPLATE'
 
+    def get_groupname(self):
+        groupname = ''
+        for hg in self.hostgroups:
+            # console_logger.info('get_groupname : %s %s %s' % (hg.id, hg.alias, hg.get_name()))
+            # groupname = "%s [%s]" % (hg.alias, hg.get_name())
+            groupname = "%s" % (hg.alias)
+        return groupname
+
+    def get_groupnames(self):
+        groupnames = ''
+        for hg in self.hostgroups:
+            # console_logger.info('get_groupnames : %s' % (hg.get_name()))
+            if groupnames == '':
+                groupnames = hg.get_name()
+            else:
+                groupnames = "%s, %s" % (groupnames, hg.get_name())
+        return groupnames
+
     # For debugging purpose only
     def get_dbg_name(self):
         return self.host_name
@@ -680,7 +717,7 @@ class Host(SchedulingItem):
     # Add a log entry with a HOST ALERT like:
     # HOST ALERT: server;DOWN;HARD;1;I don't know what to say...
     def raise_alert_log_entry(self):
-        console_logger.info('HOST ALERT: %s;%s;%s;%d;%s'
+        console_logger.alert('HOST ALERT: %s;%s;%s;%d;%s'
                             % (self.get_name(),
                                self.state, self.state_type,
                                self.attempt, self.output))
@@ -717,7 +754,7 @@ class Host(SchedulingItem):
         else:
             state = self.state
         if self.__class__.log_notifications:
-            console_logger.info("HOST NOTIFICATION: %s;%s;%s;%s;%s"
+            console_logger.alert("HOST NOTIFICATION: %s;%s;%s;%s;%s"
                                 % (contact.get_name(), self.get_name(),
                                    state, command.get_name(), self.output))
 
@@ -725,7 +762,7 @@ class Host(SchedulingItem):
     # HOST NOTIFICATION: superadmin;server;UP;notify-by-rss;no output
     def raise_event_handler_log_entry(self, command):
         if self.__class__.log_event_handlers:
-            console_logger.info("HOST EVENT HANDLER: %s;%s;%s;%s;%s"
+            console_logger.alert("HOST EVENT HANDLER: %s;%s;%s;%s;%s"
                                 % (self.get_name(),
                                    self.state, self.state_type,
                                    self.attempt, command.get_name()))
@@ -733,7 +770,7 @@ class Host(SchedulingItem):
     # Raise a log entry with FLAPPING START alert like
     # HOST FLAPPING ALERT: server;STARTED; Host appears to have started flapping (50.6% change >= 50.0% threshold)
     def raise_flapping_start_log_entry(self, change_ratio, threshold):
-        console_logger.info("HOST FLAPPING ALERT: %s;STARTED; "
+        console_logger.alert("HOST FLAPPING ALERT: %s;STARTED; "
                             "Host appears to have started flapping "
                             "(%.1f%% change >= %.1f%% threshold)"
                             % (self.get_name(), change_ratio, threshold))
@@ -741,7 +778,7 @@ class Host(SchedulingItem):
     # Raise a log entry with FLAPPING STOP alert like
     # HOST FLAPPING ALERT: server;STOPPED; host appears to have stopped flapping (23.0% change < 25.0% threshold)
     def raise_flapping_stop_log_entry(self, change_ratio, threshold):
-        console_logger.info("HOST FLAPPING ALERT: %s;STOPPED; "
+        console_logger.alert("HOST FLAPPING ALERT: %s;STOPPED; "
                             "Host appears to have stopped flapping "
                             "(%.1f%% change < %.1f%% threshold)"
                             % (self.get_name(), change_ratio, threshold))
@@ -755,21 +792,21 @@ class Host(SchedulingItem):
     # Raise a log entry when a downtime begins
     # HOST DOWNTIME ALERT: test_host_0;STARTED; Host has entered a period of scheduled downtime
     def raise_enter_downtime_log_entry(self):
-        console_logger.info("HOST DOWNTIME ALERT: %s;STARTED; "
+        console_logger.alert("HOST DOWNTIME ALERT: %s;STARTED; "
                             "Host has entered a period of scheduled downtime"
                             % (self.get_name()))
 
     # Raise a log entry when a downtime has finished
     # HOST DOWNTIME ALERT: test_host_0;STOPPED; Host has exited from a period of scheduled downtime
     def raise_exit_downtime_log_entry(self):
-        console_logger.info("HOST DOWNTIME ALERT: %s;STOPPED; Host has "
+        console_logger.alert("HOST DOWNTIME ALERT: %s;STOPPED; Host has "
                             "exited from a period of scheduled downtime"
                             % (self.get_name()))
 
     # Raise a log entry when a downtime prematurely ends
     # HOST DOWNTIME ALERT: test_host_0;CANCELLED; Service has entered a period of scheduled downtime
     def raise_cancel_downtime_log_entry(self):
-        console_logger.info("HOST DOWNTIME ALERT: %s;CANCELLED; "
+        console_logger.alert("HOST DOWNTIME ALERT: %s;CANCELLED; "
                             "Scheduled downtime for host has been cancelled."
                             % (self.get_name()))
 
@@ -911,6 +948,14 @@ class Host(SchedulingItem):
         if self.is_flapping and type not in ('FLAPPINGSTART', 'FLAPPINGSTOP', 'FLAPPINGDISABLED'):
             return True
 
+        # Block if business rule smart notifications is enabled and all its
+        # childs have been acknowledged or are under downtime.
+        if self.got_business_rule is True \
+                and self.business_rule_smart_notifications is True \
+                and self.business_rule_notification_is_blocked() is True \
+                and type == 'PROBLEM':
+            return True
+
         return False
 
     # Get a oc*p command if item has obsess_over_*
@@ -990,7 +1035,7 @@ class Hosts(Items):
         self.linkify_with_triggers(triggers)
         self.linkify_with_checkmodulations(checkmodulations)
         self.linkify_with_macromodulations(macromodulations)
-        
+
 
     # Fill address by host_name if not set
     def fill_predictive_missing_parameters(self):
@@ -1010,7 +1055,7 @@ class Hosts(Items):
                     new_parents.append(p)
                 else:
                     err = "the parent '%s' on host '%s' is unknown!" % (parent, h.get_name())
-                    self.configuration_errors.append(err)
+                    self.configuration_warnings.append(err)
             #print "Me,", h.host_name, "define my parents", new_parents
             # We find the id, we replace the names
             h.parents = new_parents
@@ -1068,6 +1113,8 @@ class Hosts(Items):
             if not h.is_tpl() and hasattr(h, 'host_name'):
                 hname = h.host_name
                 if hasattr(h, 'hostgroups'):
+                    if isinstance(h.hostgroups, list):
+                        h.hostgroups = ','.join(h.hostgroups)
                     hgs = h.hostgroups.split(',')
                     for hg in hgs:
                         hostgroups.add_member(hname, hg.strip())
@@ -1086,7 +1133,7 @@ class Hosts(Items):
                 cc = getattr(h, prop, None)
                 if cc:
                     cc.late_linkify_with_command(commands)
-            
+
             # Ok also link checkmodulations
             for cw in h.checkmodulations:
                 cw.late_linkify_cw_by_commands(commands)
@@ -1135,17 +1182,26 @@ class Hosts(Items):
     # a template that use it
     def find_hosts_that_use_template(self, tpl_name):
         res = set()
+        tpl_name = tpl_name.strip()
 
         # First find the template
         tpl = None
         for h in self:
             # Look for template with the good name
-            if h.is_tpl() and hasattr(h, 'name') and h.name.strip() == tpl_name.strip():
+            if h.is_tpl() and hasattr(h, 'name') and h.name.strip() == tpl_name:
                 tpl = h
 
-        # If we find none, we return nothing (easy case:) )
+        # If we find none, we should manually lookup all hosts to find this 'tag'
         if tpl is None:
-            return []
+            for h in self:
+                if not hasattr(h, 'host_name') or h.is_tpl():
+                    continue
+                # Manually lookup for the templates defines in use
+                tnames = strip_and_uniq(getattr(h, 'use', '').split(','))
+                if tpl_name in tnames:
+                    res.add(h.host_name)
+
+            return list(res)
 
         # Ok, we find the tpl. We should find its father template too
         for t in self.templates.values():
