@@ -35,6 +35,8 @@ If Arbiter wants it to have a new conf, the satellite forgets the previous
  Schedulers (and actions into) and takes the new ones.
 """
 
+
+
 # Try to see if we are in an android device or not
 is_android = True
 try:
@@ -56,28 +58,19 @@ import sys
 import cPickle
 import traceback
 import socket
+import zlib
+import base64
+import threading
 
-try:
-    import shinken.pyro_wrapper as pyro
-except ImportError:
-    sys.exit("Shinken require the Python Pyro module. Please install it.")
-
-Pyro = pyro.Pyro
-PYRO_VERSION = pyro.PYRO_VERSION
+from shinken.http_daemon import HTTPDaemon
+from shinken.http_client import HTTPClient, HTTPExceptions
 
 from shinken.message import Message
 from shinken.worker import Worker
 from shinken.load import Load
 from shinken.daemon import Daemon, Interface
 from shinken.log import logger
-#from shinken.brok import Brok  # Unused
-#from shinken.check import Check  # Unused
-#from shinken.notification import Notification  # Unused
-#from shinken.eventhandler import EventHandler  # Unused
-#from shinken.external_command import ExternalCommand  # Unused
 
-# Pack of common Pyro exceptions
-from shinken.pyro_wrapper import Pyro_exp_pack
 
 
 # Class to tell that we are facing a non worker module
@@ -90,6 +83,7 @@ class NotWorkerMod(Exception):
 # It gives us our conf
 class IForArbiter(Interface):
 
+    doc = 'Remove a scheduler connexion (internal)'
     # Arbiter ask us to do not manage a scheduler_id anymore
     # I do it and don't ask why
     def remove_from_conf(self, sched_id):
@@ -97,13 +91,19 @@ class IForArbiter(Interface):
             del self.app.schedulers[sched_id]
         except KeyError:
             pass
-
+    remove_from_conf.doc = doc
+    
+    
+    doc = 'Return the managed configuration ids (internal)'
     # Arbiter ask me which sched_id I manage, If it is not ok with it
     # It will ask me to remove one or more sched_id
     def what_i_managed(self):
         logger.debug("The arbiter asked me what I manage. It's %s" % self.app.what_i_managed())
-        return self.app.what_i_managed()  # self.app.schedulers.keys()
-
+        return self.app.what_i_managed()
+    what_i_managed.need_lock = False
+    what_i_managed.doc = doc
+    
+    doc = 'Ask the daemon to drop its configuration and wait for a new one'
     # Call by arbiter if it thinks we are running but we must do not (like
     # if I was a spare that take a conf but the master returns, I must die
     # and wait a new conf)
@@ -115,27 +115,48 @@ class IForArbiter(Interface):
         logger.debug("Arbiter wants me to wait for a new configuration")
         self.app.schedulers.clear()
         self.app.cur_conf = None
+    wait_new_conf.doc = doc
 
-    # <WTF??> Inconsistent comments!
-    # methods are only used by the arbiter or the broker?
+
+    doc = 'Push broks objects to the daemon (internal)'
     # NB: following methods are only used by broker
     # Used by the Arbiter to push broks to broker
-    # </WTF??>
     def push_broks(self, broks):
-        self.app.add_broks_to_queue(broks.values())
-        return True
-
+        with self.app.arbiter_broks_lock:
+            self.app.arbiter_broks.extend(broks.values())
+    push_broks.method = 'post'
+    # We are using a Lock just for NOT lock this call from the arbiter :)
+    push_broks.need_lock = False
+    push_broks.doc = doc
+    
+    
+    doc = 'Get the external commands from the daemon (internal)'
     # The arbiter ask us our external commands in queue
+    # Same than push_broks, we will not using Global lock here,
+    # and only lock for external_commands
     def get_external_commands(self):
-        return self.app.get_external_commands()
+        with self.app.external_commands_lock:
+            cmds = self.app.get_external_commands()
+            raw = cPickle.dumps(cmds)
+        return raw
+    get_external_commands.need_lock = False
+    get_external_commands.doc = doc
 
+    
+    doc = 'Does the daemon got configuration (receiver)'
     ### NB: only useful for receiver
     def got_conf(self):
         return self.app.cur_conf is not None
+    got_conf.need_lock = False
+    got_conf.doc = doc
 
+
+    doc = 'Push hostname/scheduler links (receiver in direct routing)'
     # Use by the receivers to got the host names managed by the schedulers
     def push_host_names(self, sched_id, hnames):
         self.app.push_host_names(sched_id, hnames)
+    push_host_names.method = 'post'
+    push_host_names.doc = doc
 
 
 class ISchedulers(Interface):
@@ -143,18 +164,22 @@ class ISchedulers(Interface):
     If we are passive, they connect to this and send/get actions
 
     """
-
+    
+    doc = 'Push new actions to the scheduler (internal)'
     # A Scheduler send me actions to do
     def push_actions(self, actions, sched_id):
-        # logger.debug("[%s] A scheduler sent me action : %s") % (self.name, actions)
-        self.app.add_actions(actions, sched_id)
+        self.app.add_actions(actions, int(sched_id))
+    push_actions.method = 'post'
+    push_actions.doc = doc
 
+    doc = 'Get the returns of the actions (internal)'
     # A scheduler ask us the action return value
     def get_returns(self, sched_id):
         #print "A scheduler ask me the returns", sched_id
-        ret = self.app.get_return_for_passive(sched_id)
+        ret = self.app.get_return_for_passive(int(sched_id))
         #print "Send mack", len(ret), "returns"
-        return ret
+        return cPickle.dumps(ret)
+    get_returns.doc = doc
 
 
 class IBroks(Interface):
@@ -164,25 +189,60 @@ class IBroks(Interface):
 
     """
 
+    doc = 'Get broks from the daemon'
     # poller or reactionner ask us actions
     def get_broks(self, bname):
         res = self.app.get_broks()
+        return base64.b64encode(zlib.compress(cPickle.dumps(res), 2))
+    get_broks.doc = doc
+
+
+class IStats(Interface):
+    """ 
+    Interface for various stats about poller/reactionner activity
+    """
+
+    doc = 'Get raw stats from the daemon'
+    def get_raw_stats(self):
+        app = self.app
+        res = {}
+        
+        for sched_id in app.schedulers:
+            sched = app.schedulers[sched_id]
+            lst = []
+            res[sched_id] = lst
+            for mod in app.q_by_mod:
+                # In workers we've got actions send to queue - queue size
+                for (i, q) in app.q_by_mod[mod].items():
+                    lst.append( {'scheduler_name' : sched['name'],
+                                 'module' : mod,
+                                 'queue_number' : i,
+                                 'queue_size' :q.qsize(),
+                                 'return_queue_len' : app.get_returns_queue_len() } )
         return res
+    get_raw_stats.doc = doc
+
+
 
 
 class BaseSatellite(Daemon):
     """Please Add a Docstring to describe the class here"""
 
     def __init__(self, name, config_file, is_daemon, do_replace, debug, debug_file):
-
-        super(BaseSatellite, self).__init__(name, config_file, is_daemon,
-                                            do_replace, debug, debug_file)
-
+        super(BaseSatellite, self).__init__(name, config_file, is_daemon, \
+                                                do_replace, debug, debug_file)
         # Ours schedulers
         self.schedulers = {}
 
         # Now we create the interfaces
         self.interface = IForArbiter(self)
+        self.istats = IStats(self)
+
+        # Can have a queue of external_commands given by modules
+        # will be taken by arbiter to process
+        self.external_commands = []
+        self.external_commands_lock = threading.RLock()
+
 
     # The arbiter can resent us new conf in the pyro_daemon port.
     # We do not want to loose time about it, so it's not a blocking
@@ -191,12 +251,14 @@ class BaseSatellite(Daemon):
     def watch_for_new_conf(self, timeout):
         self.handleRequests(timeout)
 
+
     def do_stop(self):
-        if self.pyro_daemon and self.interface:
+        if self.http_daemon and self.interface:
             logger.info("[%s] Stopping all network connections" % self.name)
-            self.pyro_daemon.unregister(self.interface)
+            self.http_daemon.unregister(self.interface)
         super(BaseSatellite, self).do_stop()
 
+
     # Give the arbiter the data about what I manage
     # for me it's the ids of my schedulers
     def what_i_managed(self):
@@ -206,6 +268,15 @@ class BaseSatellite(Daemon):
         return r
 
 
+    # Call by arbiter to get our external commands
+    def get_external_commands(self):
+        res = self.external_commands
+        self.external_commands = []
+        return res
+
+
+
+
 class Satellite(BaseSatellite):
     """Our main APP class"""
 
@@ -233,13 +304,8 @@ class Satellite(BaseSatellite):
         self.returns_queue = None
         self.q_by_mod = {}
 
-        # Not used for now
-        #self.max_q_size = 42
-
-        # Can have a queue of external_commands given by modules
-        # will be taken by arbiter to process
-        self.external_commands = []
 
+    
     # Initialize or re-initialize connection with scheduler """
     def pynag_con_init(self, id):
         sched = self.schedulers[id]
@@ -255,28 +321,19 @@ class Satellite(BaseSatellite):
         logger.info("[%s] Init connection with %s at %s" % (self.name, sname, uri))
 
         try:
-            socket.setdefaulttimeout(3)
-            sch_con = sched['con'] = Pyro.core.getProxyForURI(uri)
-            socket.setdefaulttimeout(None)
-        except Pyro_exp_pack, exp:
-            # But the multiprocessing module is not compatible with it!
-            # so we must disable it immediately after
-            socket.setdefaulttimeout(None)
-            logger.warning("[%s] Scheduler %s is not initialized or has network problem: %s" %
-                           (self.name, sname, str(exp)))
+            sch_con = sched['con'] = HTTPClient(uri=uri, strong_ssl=sched['hard_ssl_name_check'])
+        except HTTPExceptions, exp:
+            logger.warning("[%s] Scheduler %s is not initialized or has network problem: %s" % (self.name, sname, str(exp)))
             sched['con'] = None
             return
 
         # timeout of 120 s
         # and get the running id
         try:
-            pyro.set_timeout(sch_con, 5)
-            new_run_id = sch_con.get_running_id()
-        except (Pyro.errors.ProtocolError, Pyro.errors.NamingError,
-                cPickle.PicklingError, KeyError, Pyro.errors.CommunicationError,
-                Pyro.errors.DaemonError), exp:
-            logger.warning("[%s] Scheduler %s is not initialized or has network problem: %s"
-                           % (self.name, sname, str(exp)))
+            new_run_id = sch_con.get('get_running_id')
+            new_run_id = float(new_run_id)
+        except (HTTPExceptions, cPickle.PicklingError, KeyError), exp:
+            logger.warning("[%s] Scheduler %s is not initialized or has network problem: %s" % (self.name, sname, str(exp)))
             sched['con'] = None
             return
 
@@ -289,6 +346,7 @@ class Satellite(BaseSatellite):
         sched['running_id'] = new_run_id
         logger.info("[%s] Connection OK with scheduler %s" % (self.name, sname))
 
+
     # Manage action returned from Workers
     # We just put them into the corresponding sched
     # and we clean unused properties like sched_id
@@ -344,29 +402,17 @@ class Satellite(BaseSatellite):
                 try:
                     con = sched['con']
                     if con is not None:  # None = not initialized
-                        send_ok = con.put_results(ret)
+                        send_ok = con.post('put_results', {'results':ret})
+
                 # Not connected or sched is gone
-                except (Pyro_exp_pack, KeyError), exp:
+                except (HTTPExceptions, KeyError), exp:
                     logger.error('manage_returns exception:: %s,%s ' % (type(exp), str(exp)))
-                    try:
-                        logger.error(''.join(PYRO_VERSION < "4.0"
-                                     and Pyro.util.getPyroTraceback(exp)
-                                     or Pyro.util.getPyroTraceback()))
-                    except:
-                        pass
                     self.pynag_con_init(sched_id)
                     return
                 except AttributeError, exp:  # the scheduler must  not be initialized
                     logger.error('manage_returns exception:: %s,%s ' % (type(exp), str(exp)))
                 except Exception, exp:
-                    logger.error("A satellite raised an unknown exception: %s (%s)"
-                                 % (exp, type(exp)))
-                    try:
-                        logger.error(''.join(PYRO_VERSION < "4.0"
-                                     and Pyro.util.getPyroTraceback(exp)
-                                     or Pyro.util.getPyroTraceback()))
-                    except:
-                        pass
+                    logger.error("A satellite raised an unknown exception: %s (%s)" % (exp, type(exp)))
                     raise
 
             # We clean ONLY if the send is OK
@@ -429,9 +475,8 @@ class Satellite(BaseSatellite):
                 return
         # We want to give to the Worker the name of the daemon (poller or reactionner)
         cls_name = self.__class__.__name__.lower()
-        w = Worker(1, q, self.returns_queue, self.processes_by_worker,
-                   mortal=mortal, max_plugins_output_length=self.max_plugins_output_length,
-                   target=target, loaded_into=cls_name)
+        w = Worker(1, q, self.returns_queue, self.processes_by_worker, \
+                   mortal=mortal, max_plugins_output_length=self.max_plugins_output_length, target=target, loaded_into=cls_name, http_daemon=self.http_daemon)
         w.module_name = module_name
         # save this worker
         self.workers[w.id] = w
@@ -455,19 +500,15 @@ class Satellite(BaseSatellite):
             except (AttributeError, AssertionError):
                 pass
         # Close the pyro server socket if it was opened
-        if self.pyro_daemon:
+        if self.http_daemon:
             if self.brok_interface:
-                self.pyro_daemon.unregister(self.brok_interface)
+                self.http_daemon.unregister(self.brok_interface)
             if self.scheduler_interface:
-                self.pyro_daemon.unregister(self.scheduler_interface)
+                self.http_daemon.unregister(self.scheduler_interface)
         # And then call our master stop from satellite code
         super(Satellite, self).do_stop()
 
-    # Call by arbiter to get our external commands
-    def get_external_commands(self):
-        res = self.external_commands
-        self.external_commands = []
-        return res
+
 
     # A simple function to add objects in self
     # like broks in self.broks, etc
@@ -481,7 +522,9 @@ class Satellite(BaseSatellite):
             return
         elif cls_type == 'externalcommand':
             logger.debug("Enqueuing an external command '%s'" % str(elt.__dict__))
-            self.external_commands.append(elt)
+            with self.external_commands_lock:
+                self.external_commands.append(elt)
+
 
     # Someone ask us our broks. We send them, and clean the queue
     def get_broks(self):
@@ -489,6 +532,7 @@ class Satellite(BaseSatellite):
         self.broks.clear()
         return res
 
+
     # workers are processes, they can die in a numerous of ways
     # like:
     # *99.99%: bug in code, sorry:p
@@ -533,17 +577,8 @@ class Satellite(BaseSatellite):
             # So now we can really forgot it
             del self.workers[id]
 
-    # Returns the max queue size for a mod
-    def get_max_q_len(self, mod):
-        max_size = 0
 
-        for _, q in self.q_by_mod[mod].items():
-            max_size = max(max_size, q.qsize())
-
-        return max_size
-
-    # Here we do not create new workers yet  if the queue load (len of verifs) is too long
-    # We only ensure we have min_workers per modules.
+    # Here we create new workers if the queue load (len of verifs) is too long
     def adjust_worker_number_by_load(self):
         to_del = []
         logger.debug("[%s] Trying to adjust worker number."
@@ -560,6 +595,7 @@ class Satellite(BaseSatellite):
                 # if so, just delete if from q_by_mod
                 except NotWorkerMod:
                     to_del.append(mod)
+                    break
             """
             # Try to really adjust load if necessary
             if self.get_max_q_len(mod) > self.max_q_size:
@@ -601,6 +637,7 @@ class Satellite(BaseSatellite):
         # return the id of the worker (i), and its queue
         return (i, q)
 
+
     # Add a list of actions to our queues
     def add_actions(self, lst, sched_id):
         for a in lst:
@@ -612,6 +649,7 @@ class Satellite(BaseSatellite):
             a.status = 'queue'
             self.assign_to_a_queue(a)
 
+
     # Take an action and put it into one queue
     def assign_to_a_queue(self, a):
         msg = Message(id=0, type='Do', data=a)
@@ -621,6 +659,7 @@ class Satellite(BaseSatellite):
         if q is not None:
             q.put(msg)
 
+
     # We get new actions from schedulers, we create a Message and we
     # put it in the s queue (from master to slave)
     # REF: doc/shinken-action-queues.png (1)
@@ -647,13 +686,19 @@ class Satellite(BaseSatellite):
                 except KeyError:
                     con = None
                 if con is not None:  # None = not initialized
-                    pyro.set_timeout(con, 120)
+                    #pyro.set_timeout(con, 120)
                     # OK, go for it :)
-                    tmp = con.get_checks(do_checks=do_checks, do_actions=do_actions,
-                                         poller_tags=self.poller_tags,
-                                         reactionner_tags=self.reactionner_tags,
-                                         worker_name=self.name,
-                                         module_types=self.q_by_mod.keys())
+                    # Before ask a call that can be long, do a simple ping to be sure it is alive
+                    con.get('ping')
+                    tmp = con.get('get_checks', {'do_checks':do_checks, 'do_actions':do_actions,
+                                                          'poller_tags':self.poller_tags,
+                                                          'reactionner_tags':self.reactionner_tags,
+                                                          'worker_name':self.name,
+                                                          'module_types':self.q_by_mod.keys()}, wait='long')
+                    # Explicit pickle load
+                    tmp = base64.b64decode(tmp)
+                    tmp = zlib.decompress(tmp)
+                    tmp = cPickle.loads(str(tmp))
                     logger.debug("Ask actions to %d, got %d" % (sched_id, len(tmp)))
                     # We 'tag' them with sched_id and put into queue for workers
                     # REF: doc/shinken-action-queues.png (2)
@@ -662,35 +707,17 @@ class Satellite(BaseSatellite):
                     self.pynag_con_init(sched_id)
             # Ok, con is unknown, so we create it
             # Or maybe is the connection lost, we recreate it
-            except (Pyro_exp_pack, KeyError), exp:
+            except (HTTPExceptions, KeyError), exp:
                 logger.debug('get_new_actions exception:: %s,%s ' % (type(exp), str(exp)))
-                try:
-                    logger.debug(''.join(PYRO_VERSION < "4.0"
-                                 and Pyro.util.getPyroTraceback(exp)
-                                 or Pyro.util.getPyroTraceback()))
-                except:
-                    pass
                 self.pynag_con_init(sched_id)
             # scheduler must not be initialized
             # or scheduler must not have checks
-            except (AttributeError, Pyro.errors.NamingError), exp:
+            except AttributeError, exp:
                 logger.debug('get_new_actions exception:: %s,%s ' % (type(exp), str(exp)))
-                try:
-                    logger.debug(''.join(PYRO_VERSION < "4.0"
-                                 and Pyro.util.getPyroTraceback(exp)
-                                 or Pyro.util.getPyroTraceback()))
-                except:
-                    pass
             # What the F**k? We do not know what happened,
             # log the error message if possible.
             except Exception, exp:
                 logger.error("A satellite raised an unknown exception: %s (%s)" % (exp, type(exp)))
-                try:
-                    logger.debug(''.join(PYRO_VERSION < "4.0"
-                                 and Pyro.util.getPyroTraceback(exp)
-                                 or Pyro.util.getPyroTraceback()))
-                except:
-                    pass
                 raise
 
     # In android we got a Queue, and a manager list for others
@@ -721,7 +748,9 @@ class Satellite(BaseSatellite):
         # Clean all lists
         self.schedulers.clear()
         self.broks.clear()
-        self.external_commands = self.external_commands[:]
+        with self.external_commands_lock:
+            self.external_commands = self.external_commands[:]
+
 
     def do_loop_turn(self):
         logger.debug("Loop turn")
@@ -830,9 +859,10 @@ class Satellite(BaseSatellite):
     def do_post_daemon_init(self):
 
         # And we register them
-        self.uri2 = self.pyro_daemon.register(self.interface, "ForArbiter")
-        self.uri3 = self.pyro_daemon.register(self.brok_interface, "Broks")
-        self.uri4 = self.pyro_daemon.register(self.scheduler_interface, "Schedulers")
+        self.uri2 = self.http_daemon.register(self.interface)#, "ForArbiter")
+        self.uri3 = self.http_daemon.register(self.brok_interface)#, "Broks")
+        self.uri4 = self.http_daemon.register(self.scheduler_interface)#, "Schedulers")
+        self.uri5 = self.http_daemon.register(self.istats)
 
         # self.s = Queue() # Global Master -> Slave
         # We can open the Queue for fork AFTER
@@ -848,10 +878,11 @@ class Satellite(BaseSatellite):
             self.returns_queue = self.manager.Queue()
 
         # For multiprocess things, we should not have
-        # socket timeouts. will be set explicitly in Pyro calls
+        # socket timeouts.
         import socket
         socket.setdefaulttimeout(None)
 
+
     # Setup the new received conf from arbiter
     def setup_new_conf(self):
         conf = self.new_conf
@@ -884,6 +915,7 @@ class Satellite(BaseSatellite):
                 old_addr = self.schedulers[sched_id]['address']
                 new_port = conf['schedulers'][sched_id]['port']
                 old_port = self.schedulers[sched_id]['port']
+
                 # Should got all the same to be ok :)
                 if new_addr == old_addr and new_port == old_port:
                     already_got = True
@@ -899,7 +931,10 @@ class Satellite(BaseSatellite):
 
             if s['name'] in g_conf['satellitemap']:
                 s.update(g_conf['satellitemap'][s['name']])
-            uri = pyro.create_uri(s['address'], s['port'], 'Checks', self.use_ssl)
+            proto = 'http'
+            if s['use_ssl']:
+                proto = 'https'
+            uri = '%s://%s:%s/' % (proto, s['address'], s['port'])
 
             self.schedulers[sched_id]['uri'] = uri
             if already_got:
@@ -976,6 +1011,8 @@ class Satellite(BaseSatellite):
 
             self.do_post_daemon_init()
 
+            self.load_modules_manager()
+
             # We wait for initial conf
             self.wait_for_initial_conf()
             if not self.new_conf:  # we must have either big problem or was requested to shutdown
