@@ -27,17 +27,13 @@ import time
 import os
 import cStringIO
 import sys
-import socket
 import tempfile
 import traceback
+import json
+import cPickle
+import zlib
 from Queue import Empty
 
-try:
-    import shinken.pyro_wrapper as pyro
-except ImportError:
-    sys.exit("Shinken require the Python Pyro module. Please install it.")
-
-from shinken.pyro_wrapper import Pyro
 from shinken.external_command import ExternalCommand
 from shinken.check import Check
 from shinken.notification import Notification
@@ -50,11 +46,7 @@ from shinken.acknowledge import Acknowledge
 from shinken.log import logger
 from shinken.util import nighty_five_percent
 from shinken.load import Load
-
-# Pack of common Pyro exceptions
-Pyro_exp_pack = (Pyro.errors.ProtocolError, Pyro.errors.URIError, \
-                    Pyro.errors.CommunicationError, \
-                    Pyro.errors.DaemonError)
+from shinken.http_client import HTTPClient, HTTPExceptions
 
 
 class Scheduler:
@@ -80,30 +72,31 @@ class Scheduler:
             2: ('consume_results', self.consume_results, 1), # incorporate checks and dependencies
             3: ('get_new_actions', self.get_new_actions, 1), # now get the news actions (checks, notif) raised
             4: ('get_new_broks', self.get_new_broks, 1), # and broks
-            5: ('delete_zombie_checks', self.delete_zombie_checks, 1),
-            6: ('delete_zombie_actions', self.delete_zombie_actions, 1),
+            5: ('scatter_master_notifications', self.scatter_master_notifications, 1),
+            6: ('delete_zombie_checks', self.delete_zombie_checks, 1),
+            7: ('delete_zombie_actions', self.delete_zombie_actions, 1),
             # 3: (self.delete_unwanted_notifications, 1),
-            7: ('check_freshness', self.check_freshness, 10),
-            8: ('clean_caches', self.clean_caches, 1),
-            9: ('update_retention_file', self.update_retention_file, 3600),
-            10: ('check_orphaned', self.check_orphaned, 60),
+            8: ('check_freshness', self.check_freshness, 10),
+            9: ('clean_caches', self.clean_caches, 1),
+            10: ('update_retention_file', self.update_retention_file, 3600),
+            11: ('check_orphaned', self.check_orphaned, 60),
             # For NagVis like tools: update our status every 10s
-            11: ('get_and_register_update_program_status_brok', self.get_and_register_update_program_status_brok, 10),
+            12: ('get_and_register_update_program_status_brok', self.get_and_register_update_program_status_brok, 10),
             # Check for system time change. And AFTER get new checks
             # so they are changed too.
-            12: ('check_for_system_time_change', self.sched_daemon.check_for_system_time_change, 1),
+            13: ('check_for_system_time_change', self.sched_daemon.check_for_system_time_change, 1),
             # launch if need all internal checks
-            13: ('manage_internal_checks', self.manage_internal_checks, 1),
+            14: ('manage_internal_checks', self.manage_internal_checks, 1),
             # clean some times possible overridden Queues, to do not explode in memory usage
             # every 1/4 of hour
-            14: ('clean_queues', self.clean_queues, 1),
+            15: ('clean_queues', self.clean_queues, 1),
             # Look for new business_impact change by modulation every minute
-            15: ('update_business_values', self.update_business_values, 60),
+            16: ('update_business_values', self.update_business_values, 60),
             # Reset the topology change flag if need
-            16: ('reset_topology_change_flag', self.reset_topology_change_flag, 1),
-            17: ('check_for_expire_acknowledge', self.check_for_expire_acknowledge, 1),
-            18: ('send_broks_to_modules', self.send_broks_to_modules, 1),
-            19: ('get_objects_from_from_queues', self.get_objects_from_from_queues, 1),
+            17: ('reset_topology_change_flag', self.reset_topology_change_flag, 1),
+            18: ('check_for_expire_acknowledge', self.check_for_expire_acknowledge, 1),
+            19: ('send_broks_to_modules', self.send_broks_to_modules, 1),
+            20: ('get_objects_from_from_queues', self.get_objects_from_from_queues, 1),
         }
 
         # stats part
@@ -144,7 +137,8 @@ class Scheduler:
         del self.waiting_results[:]
         for o in self.checks, self.actions, self.downtimes, self.contact_downtimes, self.comments, self.broks, self.brokers:
             o.clear()
-        
+
+
 
     # Load conf for future use
     # we are in_test if the data are from an arbiter object like,
@@ -243,7 +237,7 @@ class Scheduler:
                 f.write(s)
             for a in self.actions.values():
                 s = '%s: %s:%s:%s:%s:%s:%s\n' % (a.__class__.my_type.upper(), a.id, a.status, a.t_to_go, a.reactionner_tag, a.command, a.worker)
-                f.write(s)                
+                f.write(s)
             for b in self.broks.values():
                 s = 'BROK: %s:%s\n' % (b.id, b.type)
                 f.write(s)
@@ -521,6 +515,60 @@ class Scheduler:
                     #print "The elements", i.get_name(), "change it's business_impact value from", was, "to", new
                     self.get_and_register_status_brok(i)
 
+
+    # Each second we search for master notification that are scatterisable and we do the job
+    # we take the sons and we put them into our actions queue
+    def scatter_master_notifications(self):
+            now = time.time()
+            for a in self.actions.values():
+                # We only want notifications
+                if a.is_a != 'notification':
+                    continue
+                if a.status == 'scheduled' and a.is_launchable(now):
+                    if not a.contact:
+                        # This is a "master" notification created by create_notifications.
+                        # It wont sent itself because it has no contact.
+                        # We use it to create "child" notifications (for the contacts and
+                        # notification_commands) which are executed in the reactionner.
+                        item = a.ref
+                        childnotifications = []
+                        if not item.notification_is_blocked_by_item(a.type, now):
+                            # If it is possible to send notifications of this type at the current time, then create
+                            # a single notification for each contact of this item.
+                            childnotifications = item.scatter_notification(a)
+                            for c in childnotifications:
+                                c.status = 'scheduled'
+                                self.add(c)  # this will send a brok
+
+                        # If we have notification_interval then schedule the next notification (problems only)
+                        if a.type == 'PROBLEM':
+                            # Update the ref notif number after raise the one of the notification
+                            if len(childnotifications) != 0:
+                                # notif_nb of the master notification was already current_notification_number+1.
+                                # If notifications were sent, then host/service-counter will also be incremented
+                                item.current_notification_number = a.notif_nb
+
+                            if item.notification_interval != 0 and a.t_to_go is not None:
+                                # We must continue to send notifications.
+                                # Just leave it in the actions list and set it to "scheduled" and it will be found again later
+                                # Ask the service/host to compute the next notif time. It can be just
+                                # a.t_to_go + item.notification_interval * item.__class__.interval_length
+                                # or maybe before because we have an escalation that need to raise up before
+                                a.t_to_go = item.get_next_notification_time(a)
+
+                                a.notif_nb = item.current_notification_number + 1
+                                a.status = 'scheduled'
+                            else:
+                                # Wipe out this master notification. One problem notification is enough.
+                                item.remove_in_progress_notification(a)
+                                self.actions[a.id].status = 'zombie'
+
+                        else:
+                            # Wipe out this master notification. We don't repeat recover/downtime/flap/etc...
+                            item.remove_in_progress_notification(a)
+                            self.actions[a.id].status = 'zombie'
+
+
     # Called by poller to get checks
     # Can get checks and actions (notifications and co)
     def get_to_run_checks(self, do_checks=False, do_actions=False,
@@ -552,71 +600,30 @@ class Scheduler:
         # If reactionner want to notify too
         if do_actions:
             for a in self.actions.values():
-                # if do_action, call the reactionner, and so reactionner_tags by default is ['None']
-                # by default reactionner_tag is 'None' and reactionner_tags is ['None'] too
-                # So if not the good one, loop for next :)
-                if not a.reactionner_tag in reactionner_tags:
-                    continue
+                is_master = (a.is_a == 'notification' and not a.contact)
 
-                # same for module_type
-                if not a.module_type in module_types:
-                    continue
+                if not is_master:
+                    # if do_action, call the reactionner, and so reactionner_tags by default is ['None']
+                    # by default reactionner_tag is 'None' and reactionner_tags is ['None'] too
+                    # So if not the good one, loop for next :)
+                    if not a.reactionner_tag in reactionner_tags:
+                        continue
+
+                    # same for module_type
+                    if not a.module_type in module_types:
+                        continue
 
                 # And now look for can launch or not :)
                 if a.status == 'scheduled' and a.is_launchable(now):
                     a.status = 'inpoller'
                     a.worker = worker_name
-                    if a.is_a == 'notification' and not a.contact:
-                        # This is a "master" notification created by create_notifications.
-                        # It wont sent itself because it has no contact.
-                        # We use it to create "child" notifications (for the contacts and
-                        # notification_commands) which are executed in the reactionner.
-                        item = a.ref
-                        childnotifications = []
-
-                        if not item.notification_is_blocked_by_item(a.type, now):
-                            # If it is possible to send notifications of this type at the current time, then create
-                            # a single notification for each contact of this item.
-                            childnotifications = item.scatter_notification(a)
-                            for c in childnotifications:
-                                c.status = 'inpoller'
-                                self.add(c)  # this will send a brok
-                                new_c = c.copy_shell()
-                                res.append(new_c)
-
-                        # If we have notification_interval then schedule the next notification (problems only)
-                        if a.type == 'PROBLEM':
-                            # Update the ref notif number after raise the one of the notification
-                            if len(childnotifications) != 0:
-                                # notif_nb of the master notification was already current_notification_number+1.
-                                # If notifications were sent, then host/service-counter will also be incremented
-                                item.current_notification_number = a.notif_nb
-
-                            if item.notification_interval != 0 and a.t_to_go is not None:
-                                # We must continue to send notifications.
-                                # Just leave it in the actions list and set it to "scheduled" and it will be found again later
-                                # Ask the service/host to compute the next notif time. It can be just
-                                # a.t_to_go + item.notification_interval * item.__class__.interval_length
-                                # or maybe before because we have an escalation that need to raise up before
-                                a.t_to_go = item.get_next_notification_time(a)
-                                
-                                a.notif_nb = item.current_notification_number + 1
-                                a.status = 'scheduled'
-                            else:
-                                # Wipe out this master notification. One problem notification is enough.
-                                item.remove_in_progress_notification(a)
-                                self.actions[a.id].status = 'zombie'
-
-                        else:
-                            # Wipe out this master notification. We don't repeat recover/downtime/flap/etc...
-                            item.remove_in_progress_notification(a)
-                            self.actions[a.id].status = 'zombie'
-                    else:
+                    if not is_master:
                         # This is for child notifications and eventhandlers
                         new_a = a.copy_shell()
                         res.append(new_a)
         return res
-
+    
+    
     # Called by poller and reactionner to send result
     def put_results(self, c):
         if c.is_a == 'notification':
@@ -657,7 +664,7 @@ class Scheduler:
 
             except AttributeError, exp:  # bad object, drop it
                 logger.warning('put_results:: get bad notification : %s ' % str(exp))
-            
+
 
 
         elif c.is_a == 'check':
@@ -665,6 +672,7 @@ class Scheduler:
                 if c.status == 'timeout':
                     c.output = "(%s Check Timed Out)" % self.checks[c.id].ref.__class__.my_type.capitalize()
                     c.long_output = c.output
+                    c.exit_status = self.conf.timeout_exit_status
                 self.checks[c.id].get_return_from(c)
                 self.checks[c.id].status = 'waitconsume'
             except KeyError, exp:
@@ -728,43 +736,28 @@ class Scheduler:
 
         uri = links[id]['uri']
         try:
-            # But the multiprocessing module is not compatible with it!
-            # so we must disable it immediately after
-            socket.setdefaulttimeout(3)
-            links[id]['con'] = Pyro.core.getProxyForURI(uri)
+            links[id]['con'] = HTTPClient(uri=uri, strong_ssl=links[id]['hard_ssl_name_check'])
             con = links[id]['con']
-            socket.setdefaulttimeout(None)
-        except Pyro_exp_pack, exp:
-            # But the multiprocessing module is not compatible with it!
-            # so we must disable it immediately after
-            socket.setdefaulttimeout(None)
+        except HTTPExceptions, exp:
             logger.warning("Connection problem to the %s %s: %s" % (type, links[id]['name'], str(exp)))
             links[id]['con'] = None
             return
 
         try:
             # initial ping must be quick
-            pyro.set_timeout(con, 5)
-            con.ping()
-        except Pyro.errors.ProtocolError, exp:
+            con.get('ping')
+        except HTTPExceptions, exp:
             logger.warning("Connection problem to the %s %s: %s" % (type, links[id]['name'], str(exp)))
             links[id]['con'] = None
             return
-        except Pyro.errors.NamingError, exp:
-            logger.warning("The %s '%s' is not initialized: %s" % (type, links[id]['name'], str(exp)))
-            links[id]['con'] = None
-            return
         except KeyError, exp:
             logger.warning("The %s '%s' is not initialized: %s" % (type, links[id]['name'], str(exp)))
             links[id]['con'] = None
             return
-        except Pyro.errors.CommunicationError, exp:
-            logger.warning("The %s '%s' got CommunicationError: %s" % (type, links[id]['name'], str(exp)))
-            links[id]['con'] = None
-            return
 
         logger.info("Connection OK to the %s %s" % (type, links[id]['name']))
 
+
     # We should push actions to our passives satellites
     def push_actions_to_passives_satellites(self):
         # We loop for our passive pollers or reactionners
@@ -777,28 +770,21 @@ class Scheduler:
                 lst = self.get_to_run_checks(True, False, poller_tags, worker_name=p['name'])
                 try:
                     # initial ping must be quick
-                    pyro.set_timeout(con, 120)
+                    #pyro.set_timeout(con, 120)
                     logger.debug("Sending %s actions" % len(lst))
-                    con.push_actions(lst, self.instance_id)
+                    #con.push_actions(lst, self.instance_id)
+                    con.post('push_actions', {'actions':lst, 'sched_id':self.instance_id})
                     self.nb_checks_send += len(lst)
-                except Pyro.errors.ProtocolError, exp:
+                except HTTPExceptions, exp:
                     logger.warning("Connection problem to the %s %s: %s" % (type, p['name'], str(exp)))
                     p['con'] = None
                     return
-                except Pyro.errors.NamingError, exp:
-                    logger.warning("The %s '%s' is not initialized: %s" % (type, p['name'], str(exp)))
-                    p['con'] = None
-                    return
                 except KeyError, exp:
                     logger.warning("The %s '%s' is not initialized: %s" % (type, p['name'], str(exp)))
                     p['con'] = None
                     return
-                except Pyro.errors.CommunicationError, exp:
-                    logger.warning("The %s '%s' got CommunicationError: %s" % (type, p['name'], str(exp)))
-                    p['con'] = None
-                    return
                 # we come back to normal timeout
-                pyro.set_timeout(con, 5)
+                #pyro.set_timeout(con, 5)
             else:  # no connection? try to reconnect
                 self.pynag_con_init(p['instance_id'], type='poller')
 
@@ -813,31 +799,25 @@ class Scheduler:
                 lst = self.get_to_run_checks(False, True, reactionner_tags=reactionner_tags, worker_name=p['name'])
                 try:
                     # initial ping must be quick
-                    pyro.set_timeout(con, 120)
+                    #pyro.set_timeout(con, 120)
                     logger.debug("Sending %d actions" % len(lst))
-                    con.push_actions(lst, self.instance_id)
+                    #con.push_actions(lst, self.instance_id)
+                    con.post('push_actions', {'actions':lst, 'sched_id':self.instance_id})
                     self.nb_checks_send += len(lst)
-                except Pyro.errors.ProtocolError, exp:
+                except HTTPExceptions, exp:
                     logger.warning("Connection problem to the %s %s: %s" % (type, p['name'], str(exp)))
                     p['con'] = None
                     return
-                except Pyro.errors.NamingError, exp:
-                    logger.warning("The %s '%s' is not initialized: %s" % (type, p['name'], str(exp)))
-                    p['con'] = None
-                    return
                 except KeyError, exp:
                     logger.warning("The %s '%s' is not initialized: %s" % (type, p['name'], str(exp)))
                     p['con'] = None
                     return
-                except Pyro.errors.CommunicationError, exp:
-                    logger.warning("The %s '%s' got CommunicationError: %s" % (type, p['name'], str(exp)))
-                    p['con'] = None
-                    return
                 # we come back to normal timeout
-                pyro.set_timeout(con, 5)
+                #pyro.set_timeout(con, 5)
             else:  # no connection? try to reconnect
                 self.pynag_con_init(p['instance_id'], type='reactionner')
 
+
     # We should get returns from satellites
     def get_actions_from_passives_satellites(self):
         # We loop for our passive pollers
@@ -848,32 +828,28 @@ class Scheduler:
             if con is not None:
                 try:
                     # initial ping must be quick
-                    pyro.set_timeout(con, 120)
-                    results = con.get_returns(self.instance_id)
+                    #pyro.set_timeout(con, 120)
+                    #results = con.get_returns(self.instance_id)
+                    # Before ask a call that can be long, do a simple ping to be sure it is alive
+                    con.get('ping')
+                    results = con.get('get_returns', {'sched_id':self.instance_id}, wait='long')
+                    results = cPickle.loads(str(results))
                     nb_received = len(results)
                     self.nb_check_received += nb_received
                     logger.debug("Received %d passive results" % nb_received)
                     for result in results:
                         result.set_type_passive()
                     self.waiting_results.extend(results)
-                except Pyro.errors.ProtocolError, exp:
+                except HTTPExceptions, exp:
                     logger.warning("Connection problem to the %s %s: %s" % (type, p['name'], str(exp)))
                     p['con'] = None
                     return
-                except Pyro.errors.NamingError, exp:
-                    logger.warning("The %s '%s' is not initialized: %s" % (type, p['name'], str(exp)))
-                    p['con'] = None
-                    return
                 except KeyError, exp:
                     logger.warning("The %s '%s' is not initialized: %s" % (type, p['name'], str(exp)))
                     p['con'] = None
                     return
-                except Pyro.errors.CommunicationError, exp:
-                    logger.warning("The %s '%s' got CommunicationError: %s" % (type, p['name'], str(exp)))
-                    p['con'] = None
-                    return
                 # we come back to normal timeout
-                pyro.set_timeout(con, 5)
+                #pyro.set_timeout(con, 5)
             else:  # no connection, try reinit
                 self.pynag_con_init(p['instance_id'], type='poller')
 
@@ -885,35 +861,32 @@ class Scheduler:
             if con is not None:
                 try:
                     # initial ping must be quick
-                    pyro.set_timeout(con, 120)
-                    results = con.get_returns(self.instance_id)
+                    #pyro.set_timeout(con, 120)
+                    #results = con.get_returns(self.instance_id)
+                    # Before ask a call that can be long, do a simple ping to be sure it is alive
+                    con.get('ping')
+                    results = con.get('get_returns', {'sched_id':self.instance_id}, wait='long')
+                    results = cPickle.loads(str(results))
                     nb_received = len(results)
                     self.nb_check_received += nb_received
                     logger.debug("Received %d passive results" % nb_received)
                     for result in results:
                         result.set_type_passive()
                     self.waiting_results.extend(results)
-                except Pyro.errors.ProtocolError, exp:
+                except HTTPExceptions, exp:
                     logger.warning("Connection problem to the %s %s: %s" % (type, p['name'], str(exp)))
                     p['con'] = None
                     return
-                except Pyro.errors.NamingError, exp:
-                    logger.warning("The %s '%s' is not initialized: %s" % (type, p['name'], str(exp)))
-                    p['con'] = None
-                    return
                 except KeyError, exp:
                     logger.warning("The %s '%s' is not initialized: %s" % (type, p['name'], str(exp)))
                     p['con'] = None
                     return
-                except Pyro.errors.CommunicationError, exp:
-                    logger.warning("The %s '%s' got CommunicationError: %s" % (type, p['name'], str(exp)))
-                    p['con'] = None
-                    return
                 # we come back to normal timeout
-                pyro.set_timeout(con, 5)
+                #pyro.set_timeout(con, 5)
             else:  # no connection, try reinit
                 self.pynag_con_init(p['instance_id'], type='reactionner')
 
+
     # Some checks are purely internal, like business based one
     # simply ask their ref to manage it when it's ok to run
     def manage_internal_checks(self):
@@ -921,7 +894,7 @@ class Scheduler:
         for c in self.checks.values():
             # must be ok to launch, and not an internal one (business rules based)
             if c.internal and c.status == 'scheduled' and c.is_launchable(now):
-                c.ref.manage_internal_check(c)
+                c.ref.manage_internal_check(self.hosts, self.services, c)
                 # it manage it, now just ask to consume it
                 # like for all checks
                 c.status = 'waitconsume'
@@ -938,7 +911,7 @@ class Scheduler:
         res.update(self.broks)
         # and clean the global broks too now
         self.broks.clear()
-        
+
         return res
 
 
@@ -1226,6 +1199,7 @@ class Scheduler:
                 "instance_id": self.instance_id,
                 "instance_name": self.instance_name,
                 "last_alive": now,
+                "interval_length": self.conf.interval_length,
                 "program_start": self.program_start,
                 "pid": os.getpid(),
                 "daemon_mode": 1,
@@ -1326,10 +1300,8 @@ class Scheduler:
 
         # Check maintenance periods
         for elt in [y for y in [x for x in self.hosts] + [x for x in self.services] if y.maintenance_period is not None]:
-            if not hasattr(elt, 'in_maintenance'):
-                setattr(elt, 'in_maintenance', False)
 
-            if not elt.in_maintenance:
+            if elt.in_maintenance is None:
                 if elt.maintenance_period.is_time_valid(now):
                     start_dt = elt.maintenance_period.get_next_valid_time_from_t(now)
                     end_dt = elt.maintenance_period.get_next_invalid_time_from_t(start_dt + 1) - 1
@@ -1341,7 +1313,7 @@ class Scheduler:
             else:
                 if not elt.in_maintenance in self.downtimes:
                     # the main downtimes has expired or was manually deleted
-                    elt.in_maintenance = False
+                    elt.in_maintenance = None
 
         #  Check the validity of contact downtimes
         for elt in self.contacts:
@@ -1452,7 +1424,7 @@ class Scheduler:
                     worker_names[a.worker] += 1
 
         for w in worker_names:
-            logger.warning("%d actions never came back for the satellite '%s'. I'm reenable them for polling" % (worker_names[w], w))
+            logger.warning("%d actions never came back for the satellite '%s'. I reenable them for polling" % (worker_names[w], w))
 
     # Each loop we are going to send our broks to our modules (if need)
     def send_broks_to_modules(self):
@@ -1509,6 +1481,10 @@ class Scheduler:
 
         gogogo = time.time()
 
+        # We must reset it if we received a new conf from the Arbiter.
+        # Otherwise, the stat check average won't be correct
+        self.nb_check_received = 0
+
         self.load_one_min = Load(initial_value=1)
         logger.debug("First loop at %d" % time.time())
         while self.must_run:
@@ -1590,6 +1566,9 @@ class Scheduler:
                 self.dump_objects()
                 self.need_objects_dump = False
 
+
+
+
         # WE must save the retention at the quit BY OURSELF
         # because our daemon will not be able to do it for us
         self.update_retention_file(True)
