@@ -51,7 +51,6 @@ class declared(object):
         logger.debug("Calling %s with arguments %s" % (self.f.func_name, args))
         return self.f(*args)
 
-
 @declared
 def up(obj, output):
     """ Set a host in UP state
@@ -143,7 +142,7 @@ def perf(obj_ref, metric_name):
         logger.debug("[trigger] I found the perfdata")
         return p[metric_name].value
     logger.debug("[trigger] I am in perf command")
-    return 1
+    return None
 
 
 @declared
@@ -179,7 +178,7 @@ def allperfs(obj_ref):
     obj = get_object(obj_ref)
     p = PerfDatas(obj.perf_data)
     logger.debug("[trigger] I get all perfdatas")
-    return dict([(metric_name, p[metric_name].value) for metric_name in p])
+    return dict([(metric.name, p[metric.name]) for metric in p])
 
 
 @declared
