@@ -28,7 +28,7 @@ from shinken_test import *
 class TestBadNotificationPeriod(ShinkenTest):
 
     def setUp(self):
-        self.setup_with_file('etc/nagios_bad_notification_period.cfg')
+        self.setup_with_file('etc/shinken_bad_notification_period.cfg')
 
     # if a notif period is bad, should be catched!
     def test_bad_notification_period(self):
