@@ -28,7 +28,7 @@ from shinken_test import *
 class TestBadRealmConf(ShinkenTest):
 
     def setUp(self):
-        self.setup_with_file('etc/nagios_bad_realm_conf.cfg')
+        self.setup_with_file('etc/shinken_bad_realm_conf.cfg')
 
     def test_bad_conf(self):
         self.assert_(not self.conf.conf_is_correct)
