@@ -28,7 +28,7 @@ from shinken_test import *
 class TestContactgroupWitoutMembers(ShinkenTest):
 
     def setUp(self):
-        self.setup_with_file('etc/nagios_contactgroup_nomembers.cfg')
+        self.setup_with_file('etc/shinken_contactgroup_nomembers.cfg')
 
     # It seems that a contact group with no member cause some crash for the arbiter.
     # should fix it :)
