@@ -28,7 +28,7 @@ from shinken_test import *
 class TestCssInCommands(ShinkenTest):
 
     def setUp(self):
-        self.setup_with_file('etc/nagios_css_in_command.cfg')
+        self.setup_with_file('etc/shinken_css_in_command.cfg')
 
     def test_dummy(self):
         r = self.conf.conf_is_correct
