@@ -28,7 +28,7 @@ from shinken_test import *
 class TestNoContact(ShinkenTest):
 
     def setUp(self):
-        self.setup_with_file('etc/nagios_nocontacts.cfg')
+        self.setup_with_file('etc/shinken_nocontacts.cfg')
 
     # Seems that Nagios allow non contacts elements, just warning
     # and not error. Should do the same.
