@@ -55,7 +55,10 @@ class PropertiesTester(object):
         for name, value in self.properties.iteritems():
             self.assertIn(name, item.properties,
                           msg='property %r not found in %s' % (name, self.item.my_type))
-            self.assertEqual(item.properties[name].default, value)
+            if hasattr(item.properties[name], 'default'):
+                if item.properties[name].default != value:
+                    print "%s, %s: %s, %s" % (name, value, item.properties[name].default, value)
+                self.assertEqual(item.properties[name].default, value)
 
     def test_all_props_are_tested(self):
         item = self.item # shortcut
@@ -67,7 +70,7 @@ class PropertiesTester(object):
             self.assertIn(name, prop_names,
                           msg='unknown property %r found' % name)
 
-class TestConfig(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestConfig(PropertiesTester, ShinkenTest):
 
     unused_props = [
         'log_file', 'object_cache_file', 'precached_object_file',
@@ -96,11 +99,12 @@ class TestConfig(PropertiesTester, ShinkenTest, unittest.TestCase):
 
     properties = dict([
         ('prefix', '/usr/local/shinken/'),
-        ('workdir', ''),
+        ('workdir', '/var/run/shinken/'),
         ('config_base_dir', ''),
+        ('modules_dir', '/var/lib/shinken/modules'),
         ('use_local_log', '1'),
         ('log_level', 'WARNING'),
-        ('local_log', 'arbiterd.log'),
+        ('local_log', '/var/log/shinken/arbiterd.log'),
         ('resource_file', '/tmp/resources.txt'),
         ('shinken_user', shinken.daemon.get_cur_user()),
         ('shinken_group', shinken.daemon.get_cur_group()),
@@ -114,7 +118,7 @@ class TestConfig(PropertiesTester, ShinkenTest, unittest.TestCase):
         ('log_archive_path', '/usr/local/shinken/var/archives'),
         ('check_external_commands', '1'),
         ('command_file', ''),
-        ('lock_file', 'arbiterd.pid'),
+        ('lock_file', '/var/run/shinken/arbiterd.pid'),
         ('state_retention_file', ''),
         ('retention_update_interval', '60'),
         ('use_syslog', '0'),
@@ -203,9 +207,9 @@ class TestConfig(PropertiesTester, ShinkenTest, unittest.TestCase):
 
         # SSL part
         ('use_ssl', '0'),
-        ('certs_dir', 'etc/certs'),
+        ('server_key', 'etc/certs/server.key'),
         ('ca_cert', 'etc/certs/ca.pem'),
-        ('server_cert', 'etc/certs/server.pem'),
+        ('server_cert', 'etc/certs/server.cert'),
         ('hard_ssl_name_check', '0'),
 
         ('human_timestamp_log', '0'),
@@ -219,6 +223,11 @@ class TestConfig(PropertiesTester, ShinkenTest, unittest.TestCase):
         ('webui_lock_file', 'webui.pid'),
         ('webui_port', '8080'),
         ('webui_host', '0.0.0.0'),
+
+        ('use_multiprocesses_serializer', '0'),
+        ('daemon_thread_pool_size', '8'),
+        ('enable_environment_macros', '1'),
+        ('timeout_exit_status', '2'),
         ])
 
     def setUp(self):
@@ -226,7 +235,7 @@ class TestConfig(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Config()
 
 
-class TestCommand(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestCommand(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -235,11 +244,13 @@ class TestCommand(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('poller_tag', 'None'),
         ('reactionner_tag', 'None'),
         ('module_type', None),
         ('timeout', '-1'),
+        ('enable_environment_macros', 0),
         ])
 
     def setUp(self):
@@ -247,7 +258,7 @@ class TestCommand(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Command()
 
 
-class TestContactgroup(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestContactgroup(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -256,6 +267,7 @@ class TestContactgroup(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('unknown_members', []),
         ('id', 0),
@@ -266,7 +278,7 @@ class TestContactgroup(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Contactgroup()
 
 
-class TestContact(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestContact(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -280,6 +292,7 @@ class TestContact(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('alias', 'none'),
         ('contactgroups', ''),
@@ -306,7 +319,7 @@ class TestContact(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Contact()
 
 
-class TestDiscoveryrule(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestDiscoveryrule(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -315,6 +328,7 @@ class TestDiscoveryrule(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('creation_type', 'service'),
         ('discoveryrule_order', '0'),
@@ -325,7 +339,7 @@ class TestDiscoveryrule(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Discoveryrule()
 
 
-class TestDiscoveryrun(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestDiscoveryrun(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -334,6 +348,7 @@ class TestDiscoveryrun(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ])
 
@@ -342,7 +357,7 @@ class TestDiscoveryrun(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Discoveryrun()
 
 
-class TestEscalation(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestEscalation(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -351,6 +366,7 @@ class TestEscalation(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('notification_interval', '-1'),
         ('escalation_period', ''),
@@ -362,7 +378,7 @@ class TestEscalation(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Escalation()
 
 
-class TestHostdependency(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestHostdependency(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -371,6 +387,7 @@ class TestHostdependency(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('dependent_hostgroup_name', ''),
         ('hostgroup_name', ''),
@@ -385,7 +402,7 @@ class TestHostdependency(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Hostdependency()
 
 
-class TestHostescalation(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestHostescalation(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -398,6 +415,7 @@ class TestHostescalation(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('notification_interval', '30'),
         ('escalation_period', ''),
@@ -409,7 +427,7 @@ class TestHostescalation(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Hostescalation()
 
 
-class TestHostextinfo(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestHostextinfo(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -418,6 +436,7 @@ class TestHostextinfo(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('notes', ''),
         ('notes_url', ''),
@@ -434,7 +453,7 @@ class TestHostextinfo(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = HostExtInfo()
 
 
-class TestHostgroup(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestHostgroup(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -443,6 +462,7 @@ class TestHostgroup(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('unknown_members', []),
         ('id', 0),
@@ -457,17 +477,18 @@ class TestHostgroup(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Hostgroup()
 
 
-class TestHost(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestHost(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
     without_default = [
         'host_name', 'alias', 'address',
-        'max_check_attempts', 'check_period', 'notification_period']
+        'check_period', 'notification_period']
 
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('display_name', ''),
         ('parents', ''),
@@ -475,6 +496,7 @@ class TestHost(PropertiesTester, ShinkenTest, unittest.TestCase):
         ('check_command', '_internal_host_up'),
         ('initial_state', 'u'),
         ('check_interval', '0'),
+        ('max_check_attempts', '1'),
         ('retry_interval', '0'),
         ('active_checks_enabled', '1'),
         ('passive_checks_enabled', '1'),
@@ -518,11 +540,20 @@ class TestHost(PropertiesTester, ShinkenTest, unittest.TestCase):
         ('business_impact', '2'),
         ('trigger', ''),
         ('trigger_name', ''),
+        ('trigger_broker_raise_enabled', '0'),
         ('time_to_orphanage', '300'),
         ('trending_policies', ''),
         ('checkmodulations', ''),
         ('macromodulations', ''),
         ('custom_views', ''),
+        ('service_overrides', ''),
+        ('service_excludes', ''),
+        ('business_rule_output_template', ''),
+        ('business_rule_smart_notifications', '0'),
+        ('business_rule_downtime_as_ack', '0'),
+        ('labels', ''),
+        ('business_rule_host_notification_options', ''),
+        ('business_rule_service_notification_options', ''),
         ])
 
     def setUp(self):
@@ -530,7 +561,7 @@ class TestHost(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Host()
 
 
-class TestModule(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestModule(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -539,6 +570,7 @@ class TestModule(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('modules', ''),
         ])
@@ -548,7 +580,7 @@ class TestModule(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Module()
 
 
-class TestNotificationway(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestNotificationway(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -561,6 +593,7 @@ class TestNotificationway(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('host_notifications_enabled', '1'),
         ('service_notifications_enabled', '1'),
@@ -572,7 +605,7 @@ class TestNotificationway(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = NotificationWay()
 
 
-class TestPack(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestPack(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -581,6 +614,7 @@ class TestPack(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ])
 
@@ -589,7 +623,7 @@ class TestPack(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Pack()
 
 
-class TestRealm(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestRealm(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -598,6 +632,7 @@ class TestRealm(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('unknown_members', []),
         ('id', 0),
@@ -612,7 +647,7 @@ class TestRealm(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Realm()
 
 
-class TestResultmodulation(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestResultmodulation(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -621,6 +656,7 @@ class TestResultmodulation(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('exit_codes_match', ''),
         ('exit_code_modulation', None),
@@ -632,7 +668,7 @@ class TestResultmodulation(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Resultmodulation()
 
 
-class TestServicedependency(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestServicedependency(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -641,6 +677,7 @@ class TestServicedependency(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('dependent_hostgroup_name', ''),
         ('hostgroup_name', ''),
@@ -656,7 +693,7 @@ class TestServicedependency(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Servicedependency()
 
 
-class TestServiceescalation(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestServiceescalation(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -669,6 +706,7 @@ class TestServiceescalation(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('notification_interval', '30'),
         ('escalation_period', ''),
@@ -680,7 +718,7 @@ class TestServiceescalation(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Serviceescalation()
 
 
-class TestServiceextinfo(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestServiceextinfo(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -689,6 +727,7 @@ class TestServiceextinfo(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('notes', ''),
         ('notes_url', ''),
@@ -701,7 +740,7 @@ class TestServiceextinfo(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = ServiceExtInfo()
 
 
-class TestServicegroup(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestServicegroup(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -710,6 +749,7 @@ class TestServicegroup(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('unknown_members', []),
         ('id', 0),
@@ -723,19 +763,21 @@ class TestServicegroup(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Servicegroup()
 
 
-class TestService(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestService(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
     without_default = [
         'host_name', 'service_description',
-        'check_command', 'max_check_attempts', 'check_interval',
+        'check_command', 'check_interval',
         'retry_interval', 'check_period', 'notification_period']
 
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
+        ('max_check_attempts', '1'),
         ('hostgroup_name', ''),
         ('display_name', ''),
         ('servicegroups', ''),
@@ -781,13 +823,21 @@ class TestService(PropertiesTester, ShinkenTest, unittest.TestCase):
         ('business_impact', '2'),
         ('trigger', ''),
         ('trigger_name', ''),
+        ('trigger_broker_raise_enabled', '0'),
         ('time_to_orphanage', '300'),
         ('trending_policies', ''),
         ('checkmodulations', ''),
-        ('macromodulations', ''),        
+        ('macromodulations', ''),
         ('aggregation', ''),
         ('service_dependencies', ''),
         ('custom_views', ''),
+        ('merge_host_contacts', '0'),
+        ('business_rule_output_template', ''),
+        ('business_rule_smart_notifications', '0'),
+        ('business_rule_downtime_as_ack', '0'),
+        ('labels', ''),
+        ('business_rule_host_notification_options', ''),
+        ('business_rule_service_notification_options', ''),
         ])
 
     def setUp(self):
@@ -795,7 +845,7 @@ class TestService(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Service()
 
 
-class TestTimeperiod(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestTimeperiod(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -804,9 +854,11 @@ class TestTimeperiod(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('alias', ''),
         ('use', ''),
+        ('definition_order', '100'),
         ('register', '1'),
         ('dateranges', []),
         ('exclude', []),
@@ -818,7 +870,7 @@ class TestTimeperiod(PropertiesTester, ShinkenTest, unittest.TestCase):
         self.item = Timeperiod()
 
 
-class TestTrigger(PropertiesTester, ShinkenTest, unittest.TestCase):
+class TestTrigger(PropertiesTester, ShinkenTest):
 
     unused_props = []
 
@@ -827,6 +879,7 @@ class TestTrigger(PropertiesTester, ShinkenTest, unittest.TestCase):
     properties = dict([
         ('imported_from', 'unknown'),
         ('use', ''),
+        ('definition_order', '100'),
         ('name', ''),
         ('code_src', ''),
         ])
